@@ -1,14 +1,13 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2020 Arnaud Rebillout
+ * Copyright (C) 2015-2021 Arnaud Rebillout
  *
- * SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-only
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,13 +15,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
-#include <glib.h>
 #include <glib-object.h>
-#include <gst/gst.h>
+#include <glib.h>
 #include <gst/audio/streamvolume.h>
+#include <gst/gst.h>
+#include <libsoup/soup.h>
 
 #include "base/glib-object-additions.h"
 #include "base/gv-base.h"
@@ -39,6 +39,7 @@
 
 //#define DEBUG_GST_TAGS
 //#define DEBUG_GST_STATE_CHANGES
+//#define DEBUG_GST_ELEMENT_SETUP
 
 /*
  * Properties
@@ -51,7 +52,7 @@ enum {
 	/* Reserved */
 	PROP_0,
 	/* Properties - refer to class_init() for more details */
-	PROP_STATE,
+	PROP_PLAYBACK_STATE,
 	PROP_STATION,
 	PROP_STREAMINFO,
 	PROP_METADATA,
@@ -65,40 +66,52 @@ enum {
 
 static GParamSpec *properties[PROP_N];
 
+/*
+ * Signals
+ */
+
+enum {
+	SIGNAL_SSL_FAILURE,
+	/* Number of signals */
+	SIGNAL_N
+};
+
+static guint signals[SIGNAL_N];
+
 /*
  * GObject definitions
  */
 
 struct _GvEnginePrivate {
 	/* GStreamer stuff */
-	GstElement    *playbin;
-	GstBus        *bus;
+	GstElement *playbin;
+	GstBus *bus;
 	/* Properties */
-	GvEngineState  state;
-	GvStation     *station;
-	GvStreaminfo  *streaminfo;
-	GvMetadata    *metadata;
-	guint          volume;
-	gboolean       mute;
-	gboolean       pipeline_enabled;
-	gchar         *pipeline_string;
+	GvEngineState state;
+	GvStation *station;
+	GvStreaminfo *streaminfo;
+	GvMetadata *metadata;
+	guint volume;
+	gboolean mute;
+	gboolean pipeline_enabled;
+	gchar *pipeline_string;
 	/* Retry on error with a delay */
-	guint          error_count;
-	guint          start_playback_timeout_id;
+	guint error_count;
+	guint start_playback_timeout_id;
 };
 
 typedef struct _GvEnginePrivate GvEnginePrivate;
 
 struct _GvEngine {
 	/* Parent instance structure */
-	GObject          parent_instance;
+	GObject parent_instance;
 	/* Private data */
 	GvEnginePrivate *priv;
 };
 
 G_DEFINE_TYPE_WITH_CODE(GvEngine, gv_engine, G_TYPE_OBJECT,
-                        G_ADD_PRIVATE(GvEngine)
-                        G_IMPLEMENT_INTERFACE(GV_TYPE_ERRORABLE, NULL))
+			G_ADD_PRIVATE(GvEngine)
+			G_IMPLEMENT_INTERFACE(GV_TYPE_ERRORABLE, NULL))
 
 /*
  * GStreamer helpers
@@ -186,8 +199,7 @@ gv_engine_reload_pipeline(GvEngine *self)
 	/* Get current audio sink */
 	g_object_get(playbin, "audio-sink", &cur_audio_sink, NULL);
 
-	DEBUG("Current audio sink: %s", cur_audio_sink ? GST_ELEMENT_NAME(cur_audio_sink) :
-	      "null (default)");
+	DEBUG("Current audio sink: %s", cur_audio_sink ? GST_ELEMENT_NAME(cur_audio_sink) : "null (default)");
 
 	/* Create a new audio sink */
 	if (pipeline_enabled == FALSE || pipeline_string == NULL) {
@@ -199,14 +211,13 @@ gv_engine_reload_pipeline(GvEngine *self)
 		if (err) {
 			WARNING("Failed to parse pipeline description: %s", err->message);
 			gv_errorable_emit_error(GV_ERRORABLE(self), _("%s: %s"),
-			                        _("Failed to parse pipeline description"),
-			                        err->message);
+						_("Failed to parse pipeline description"),
+						err->message);
 			g_error_free(err);
 		}
 	}
 
-	DEBUG("New audio sink: %s", new_audio_sink ? GST_ELEMENT_NAME(new_audio_sink) :
-	      "null (default)");
+	DEBUG("New audio sink: %s", new_audio_sink ? GST_ELEMENT_NAME(new_audio_sink) : "null (default)");
 
 	/* True when one of them is NULL */
 	if (cur_audio_sink != new_audio_sink) {
@@ -243,7 +254,7 @@ gv_engine_set_state(GvEngine *self, GvEngineState state)
 		return;
 
 	priv->state = state;
-	g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_STATE]);
+	g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_PLAYBACK_STATE]);
 }
 
 GvStation *
@@ -267,6 +278,24 @@ gv_engine_get_streaminfo(GvEngine *self)
 	return self->priv->streaminfo;
 }
 
+static void
+gv_engine_update_streaminfo_from_element_setup(GvEngine *self, GstElement *element)
+{
+	GvEnginePrivate *priv = self->priv;
+	gboolean notify = FALSE;
+
+	if (priv->streaminfo == NULL) {
+		priv->streaminfo = gv_streaminfo_new();
+		notify = TRUE;
+	}
+
+	if (gv_streaminfo_update_from_element_setup(priv->streaminfo, element) == TRUE)
+		notify = TRUE;
+
+	if (notify)
+		g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_STREAMINFO]);
+}
+
 static void
 gv_engine_update_streaminfo_from_tags(GvEngine *self, GstTagList *taglist)
 {
@@ -379,7 +408,7 @@ gv_engine_set_volume(GvEngine *self, guint volume)
 
 	gst_volume = (gdouble) volume / 100.0;
 	gst_stream_volume_set_volume(GST_STREAM_VOLUME(priv->playbin),
-	                             GST_STREAM_VOLUME_FORMAT_CUBIC, gst_volume);
+				     GST_STREAM_VOLUME_FORMAT_CUBIC, gst_volume);
 
 	g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_VOLUME]);
 }
@@ -450,17 +479,17 @@ gv_engine_set_pipeline_string(GvEngine *self, const gchar *pipeline_string)
 }
 
 static void
-gv_engine_get_property(GObject    *object,
-                       guint       property_id,
-                       GValue     *value,
-                       GParamSpec *pspec)
+gv_engine_get_property(GObject *object,
+		       guint property_id,
+		       GValue *value,
+		       GParamSpec *pspec)
 {
 	GvEngine *self = GV_ENGINE(object);
 
 	TRACE_GET_PROPERTY(object, property_id, value, pspec);
 
 	switch (property_id) {
-	case PROP_STATE:
+	case PROP_PLAYBACK_STATE:
 		g_value_set_enum(value, gv_engine_get_state(self));
 		break;
 	case PROP_STATION:
@@ -491,10 +520,10 @@ gv_engine_get_property(GObject    *object,
 }
 
 static void
-gv_engine_set_property(GObject      *object,
-                       guint         property_id,
-                       const GValue *value,
-                       GParamSpec   *pspec)
+gv_engine_set_property(GObject *object,
+		       guint property_id,
+		       const GValue *value,
+		       GParamSpec *pspec)
 {
 	GvEngine *self = GV_ENGINE(object);
 
@@ -535,7 +564,7 @@ gv_engine_play(GvEngine *self, GvStation *station)
 	station_stream_uri = gv_station_get_first_stream_uri(station);
 	if (station_stream_uri == NULL) {
 		WARNING("Station '%s' has no stream uri",
-		        gv_station_get_name_or_uri(station));
+			gv_station_get_name_or_uri(station));
 		return;
 	}
 
@@ -598,33 +627,54 @@ gv_engine_new(void)
 
 static void
 on_playbin_audio_pad_notify_caps(GstPad *pad,
-		GParamSpec *pspec,
-		GvEngine *self)
+				 GParamSpec *pspec,
+				 GvEngine *self)
 {
+	/* WARNING! We're likely in the GStreamer streaming thread! */
+
 	const gchar *property_name = g_param_spec_get_name(pspec);
 	GstElement *playbin = self->priv->playbin;
 	GstMessage *msg;
 
-	/* WARNING! We're likely in the GStreamer streaming thread! */
-
 	TRACE("%p, %s, %p", pad, property_name, self);
 
 	msg = gst_message_new_application(GST_OBJECT(playbin),
-			gst_structure_new_empty("audio-caps-changed"));
+					  gst_structure_new_empty("audio-caps-changed"));
 	gst_element_post_message(playbin, msg);
 }
 
 static void
-on_playbin_source_setup(GstElement *playbin G_GNUC_UNUSED,
-                        GstElement *source,
-                        GvEngine   *self)
+on_playbin_element_setup(GstElement *playbin G_GNUC_UNUSED,
+			 GstElement *element,
+			 GvEngine *self)
 {
+	/* WARNING! We're likely in the GStreamer streaming thread! */
+
+#ifdef DEBUG_GST_ELEMENT_SETUP
+	gchar *element_name;
+	element_name = gst_element_get_name(element);
+	DEBUG("Element setup: %s", element_name);
+	g_free(element_name);
+#endif
+
+	gv_engine_update_streaminfo_from_element_setup(self, element);
+}
+
+static void
+on_playbin_source_setup(GstElement *playbin G_GNUC_UNUSED,
+			GstElement *source,
+			GvEngine *self)
+{
+	/* WARNING! We're likely in the GStreamer streaming thread! */
+
 	GvEnginePrivate *priv = self->priv;
 	GvStation *station = priv->station;
 	static gchar *default_user_agent;
 	const gchar *user_agent;
+	gboolean ssl_strict;
 
-	/* WARNING! We're likely in the GStreamer streaming thread! */
+	if (station == NULL)
+		return;
 
 	if (default_user_agent == NULL) {
 		gchar *gst_version;
@@ -634,18 +684,15 @@ on_playbin_source_setup(GstElement *playbin G_GNUC_UNUSED,
 		g_free(gst_version);
 	}
 
-	user_agent = default_user_agent;
+	user_agent = gv_station_get_user_agent(station);
+	if (user_agent == NULL)
+		user_agent = default_user_agent;
 
-	if (station) {
-		const gchar *station_user_agent;
+	ssl_strict = gv_station_get_insecure(station) ? FALSE : TRUE;
 
-		station_user_agent = gv_station_get_user_agent(station);
-		if (station_user_agent)
-			user_agent = station_user_agent;
-	}
-
-	g_object_set(source, "user-agent", user_agent, NULL);
-	DEBUG("Source setup with user-agent '%s'", user_agent);
+	g_object_set(source, "user-agent", user_agent, "ssl-strict", ssl_strict, NULL);
+	DEBUG("Source setup: ssl-strict=%s, user-agent='%s'",
+	      ssl_strict ? "true" : "false", user_agent);
 }
 
 /*
@@ -692,7 +739,7 @@ retry_playback(GvEngine *self)
 
 	INFO("Restarting playback in %u seconds", delay);
 	priv->start_playback_timeout_id =
-	        g_timeout_add_seconds(delay, when_timeout_start_playback, self);
+		g_timeout_add_seconds(delay, when_timeout_start_playback, self);
 }
 
 static void
@@ -720,7 +767,7 @@ on_bus_message_error(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self)
 {
 	GvEnginePrivate *priv = self->priv;
 	GError *err;
-	gchar  *debug;
+	gchar *debug;
 
 	priv->error_count++;
 
@@ -729,24 +776,48 @@ on_bus_message_error(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self)
 
 	/* Display error */
 	WARNING("Gst bus error msg: %s:%d: %s",
-	        g_quark_to_string(err->domain), err->code, err->message);
+		g_quark_to_string(err->domain), err->code, err->message);
 	WARNING("Gst bus error debug: %s", debug);
 
+	/* Stop playback otherwise gst keeps on spitting errors */
+	set_gst_state(priv->playbin, GST_STATE_NULL);
+
+	/* Here comes the actual effort to handle errors. At the moment there's
+	 * not much to it, we only handle SSL failures.
+	 */
+	if (g_error_matches(err, GST_RESOURCE_ERROR, GST_RESOURCE_ERROR_OPEN_READ)) {
+		const GstStructure *details = NULL;
+		gst_message_parse_error_details(msg, &details);
+		if (details && gst_structure_has_field_typed(details, "http-status-code", G_TYPE_UINT)) {
+			guint code = 0;
+			gst_structure_get_uint(details, "http-status-code", &code);
+			if (code == SOUP_STATUS_SSL_FAILED)
+				g_signal_emit(self, signals[SIGNAL_SSL_FAILURE], 0, err->message, debug);
+		}
+	} else {
+		/* When in doubt, retry! */
+		if (self->priv->state != GV_ENGINE_STATE_STOPPED)
+			retry_playback(self);
+	}
+
 	/* Cleanup */
 	g_error_free(err);
 	g_free(debug);
 
-	/* Stop immediately otherwise gst keeps on spitting errors */
-	set_gst_state(priv->playbin, GST_STATE_NULL);
-
-	/* Restart playback on error */
-	if (self->priv->state != GV_ENGINE_STATE_STOPPED)
-		retry_playback(self);
-
 	/* Emit an error signal */
 	//gv_errorable_emit_error(GV_ERRORABLE(self), "GStreamer error: %s", err->message);
 
 	/* Here are some gst error messages that I've dealt with so far.
+	 *
+	 * GST_RESOURCE_ERROR: GST_RESOURCE_ERROR_OPEN_READ
+	 *
+	 * Secure connection setup failed.
+	 *
+	 *   The protocol is https, however the server failed to return a valid
+	 *   certificate. Note that souphttpsrc has a 'ssl-strict' property that
+	 *   default to true. Setting it to false might be enough to play the stream.
+	 *
+	 *   See #128.
 	 *
 	 * GST_RESOURCE_ERROR: GST_RESOURCE_ERROR_NOT_FOUND
 	 *
@@ -764,7 +835,7 @@ on_bus_message_error(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self)
 	 *
 	 * File Not Found
 	 *
-	 *   It means that the protocol (http, lilely) is correct, the server
+	 *   It means that the protocol (http, likely) is correct, the server
 	 *   name as well, but the file is wrong or couldn't be found. I guess
 	 *   the server could be reached and replied something like "file not found".
 	 *
@@ -802,7 +873,7 @@ static void
 on_bus_message_warning(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self G_GNUC_UNUSED)
 {
 	GError *warning;
-	gchar  *debug;
+	gchar *debug;
 
 	/* Parse message */
 	gst_message_parse_warning(msg, &warning, &debug);
@@ -821,7 +892,7 @@ static void
 on_bus_message_info(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self G_GNUC_UNUSED)
 {
 	GError *info;
-	gchar  *debug;
+	gchar *debug;
 
 	/* Parse message */
 	gst_message_parse_info(msg, &info, &debug);
@@ -839,7 +910,7 @@ on_bus_message_info(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self G
 #ifdef DEBUG_GST_TAGS
 static void
 tag_list_foreach_dump(const GstTagList *list, const gchar *tag,
-                      gpointer data G_GNUC_UNUSED)
+		      gpointer data G_GNUC_UNUSED)
 {
 	gchar *str = NULL;
 
@@ -879,7 +950,6 @@ tag_list_foreach_dump(const GstTagList *list, const gchar *tag,
 	      gst_tag_list_get_tag_size(list, tag),
 	      str);
 	g_free(str);
-
 }
 #endif /* DEBUG_GST_TAGS */
 
@@ -980,7 +1050,7 @@ on_bus_message_buffering(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *s
 
 static void
 on_bus_message_state_changed(GstBus *bus G_GNUC_UNUSED, GstMessage *msg,
-                             GvEngine *self G_GNUC_UNUSED)
+			     GvEngine *self G_GNUC_UNUSED)
 {
 #ifdef DEBUG_GST_STATE_CHANGES
 	GstState old, new, pending;
@@ -1000,7 +1070,7 @@ on_bus_message_state_changed(GstBus *bus G_GNUC_UNUSED, GstMessage *msg,
 
 static void
 on_bus_message_stream_start(GstBus *bus G_GNUC_UNUSED, GstMessage *msg,
-                            GvEngine *self)
+			    GvEngine *self)
 {
 	GvEnginePrivate *priv = self->priv;
 	GstElement *playbin = priv->playbin;
@@ -1010,16 +1080,19 @@ on_bus_message_stream_start(GstBus *bus G_GNUC_UNUSED, GstMessage *msg,
 	DEBUG("Stream started");
 
 	g_signal_emit_by_name(playbin, "get-audio-pad", 0, &pad);
-	gv_engine_update_streaminfo_from_audio_pad(self, pad);
+	if (pad == NULL) {
+		DEBUG("No audio pad after stream started");
+		return;
+	}
 
-	if (pad != NULL)
-		g_signal_connect_object(pad, "notify::caps",
+	g_signal_connect_object(pad, "notify::caps",
 				G_CALLBACK(on_playbin_audio_pad_notify_caps), self, 0);
+	gv_engine_update_streaminfo_from_audio_pad(self, pad);
 }
 
 static void
 on_bus_message_application(GstBus *bus G_GNUC_UNUSED, GstMessage *msg,
-                           GvEngine *self)
+			   GvEngine *self)
 {
 	GvEnginePrivate *priv = self->priv;
 	const GstStructure *s;
@@ -1090,9 +1163,9 @@ gv_engine_constructed(GObject *object)
 
 	/* Initialize properties */
 	priv->volume = DEFAULT_VOLUME;
-	priv->mute   = DEFAULT_MUTE;
+	priv->mute = DEFAULT_MUTE;
 	priv->pipeline_enabled = FALSE;
-	priv->pipeline_string  = NULL;
+	priv->pipeline_string = NULL;
 
 	/* GStreamer must be initialized, let's check that */
 	g_assert(gst_is_initialized());
@@ -1108,8 +1181,10 @@ gv_engine_constructed(GObject *object)
 	g_object_set(playbin, "video-sink", fakesink, NULL);
 
 	/* Connect playbin signal handlers */
+	g_signal_connect_object(playbin, "element-setup",
+				G_CALLBACK(on_playbin_element_setup), self, 0);
 	g_signal_connect_object(playbin, "source-setup",
-		G_CALLBACK(on_playbin_source_setup), self, 0);
+				G_CALLBACK(on_playbin_source_setup), self, 0);
 
 	/* Get a reference to the message bus - returns full ref */
 	bus = gst_element_get_bus(playbin);
@@ -1121,23 +1196,23 @@ gv_engine_constructed(GObject *object)
 
 	/* Connect bus signal handlers */
 	g_signal_connect_object(bus, "message::eos",
-	                        G_CALLBACK(on_bus_message_eos), self, 0);
+				G_CALLBACK(on_bus_message_eos), self, 0);
 	g_signal_connect_object(bus, "message::error",
-	                        G_CALLBACK(on_bus_message_error), self, 0);
+				G_CALLBACK(on_bus_message_error), self, 0);
 	g_signal_connect_object(bus, "message::warning",
-	                        G_CALLBACK(on_bus_message_warning), self, 0);
+				G_CALLBACK(on_bus_message_warning), self, 0);
 	g_signal_connect_object(bus, "message::info",
-	                        G_CALLBACK(on_bus_message_info), self, 0);
+				G_CALLBACK(on_bus_message_info), self, 0);
 	g_signal_connect_object(bus, "message::tag",
-	                        G_CALLBACK(on_bus_message_tag), self, 0);
+				G_CALLBACK(on_bus_message_tag), self, 0);
 	g_signal_connect_object(bus, "message::buffering",
-	                        G_CALLBACK(on_bus_message_buffering), self, 0);
+				G_CALLBACK(on_bus_message_buffering), self, 0);
 	g_signal_connect_object(bus, "message::state-changed",
-	                        G_CALLBACK(on_bus_message_state_changed), self, 0);
+				G_CALLBACK(on_bus_message_state_changed), self, 0);
 	g_signal_connect_object(bus, "message::stream-start",
-	                        G_CALLBACK(on_bus_message_stream_start), self, 0);
+				G_CALLBACK(on_bus_message_stream_start), self, 0);
 	g_signal_connect_object(bus, "message::application",
-	                        G_CALLBACK(on_bus_message_application), self, 0);
+				G_CALLBACK(on_bus_message_application), self, 0);
 
 	/* Chain up */
 	G_OBJECT_CHAINUP_CONSTRUCTED(gv_engine, object);
@@ -1167,45 +1242,51 @@ gv_engine_class_init(GvEngineClass *class)
 	object_class->get_property = gv_engine_get_property;
 	object_class->set_property = gv_engine_set_property;
 
-	properties[PROP_STATE] =
-	        g_param_spec_enum("state", "Playback state", NULL,
-	                          GV_TYPE_ENGINE_STATE,
-	                          GV_ENGINE_STATE_STOPPED,
-	                          GV_PARAM_READABLE);
+	properties[PROP_PLAYBACK_STATE] =
+		g_param_spec_enum("playback-state", "Playback state", NULL,
+				  GV_TYPE_ENGINE_STATE,
+				  GV_ENGINE_STATE_STOPPED,
+				  GV_PARAM_READABLE);
 
 	properties[PROP_STATION] =
-	        g_param_spec_object("station", "Current station", NULL,
-	                            GV_TYPE_STATION,
-	                            GV_PARAM_READABLE);
+		g_param_spec_object("station", "Current station", NULL,
+				    GV_TYPE_STATION,
+				    GV_PARAM_READABLE);
 
 	properties[PROP_STREAMINFO] =
-	        g_param_spec_boxed("streaminfo", "Stream information", NULL,
-	                            GV_TYPE_STREAMINFO,
-	                            GV_PARAM_READABLE);
+		g_param_spec_boxed("streaminfo", "Stream information", NULL,
+				   GV_TYPE_STREAMINFO,
+				   GV_PARAM_READABLE);
 
 	properties[PROP_METADATA] =
-	        g_param_spec_boxed("metadata", "Stream metadata", NULL,
-	                           GV_TYPE_METADATA,
-	                           GV_PARAM_READABLE);
+		g_param_spec_boxed("metadata", "Stream metadata", NULL,
+				   GV_TYPE_METADATA,
+				   GV_PARAM_READABLE);
 
 	properties[PROP_VOLUME] =
-	        g_param_spec_uint("volume", "Volume in percent", NULL,
-	                          0, 100, DEFAULT_VOLUME,
-	                          GV_PARAM_READWRITE);
+		g_param_spec_uint("volume", "Volume in percent", NULL,
+				  0, 100, DEFAULT_VOLUME,
+				  GV_PARAM_READWRITE);
 
 	properties[PROP_MUTE] =
-	        g_param_spec_boolean("mute", "Mute", NULL,
-	                             FALSE,
-	                             GV_PARAM_READWRITE);
+		g_param_spec_boolean("mute", "Mute", NULL,
+				     FALSE,
+				     GV_PARAM_READWRITE);
 
 	properties[PROP_PIPELINE_ENABLED] =
-	        g_param_spec_boolean("pipeline-enabled", "Enable custom pipeline", NULL,
-	                             FALSE,
-	                             GV_PARAM_READWRITE);
+		g_param_spec_boolean("pipeline-enabled", "Enable custom pipeline", NULL,
+				     FALSE,
+				     GV_PARAM_READWRITE);
 
 	properties[PROP_PIPELINE_STRING] =
-	        g_param_spec_string("pipeline-string", "Custom pipeline string", NULL, NULL,
-	                            GV_PARAM_READWRITE);
+		g_param_spec_string("pipeline-string", "Custom pipeline string", NULL, NULL,
+				    GV_PARAM_READWRITE);
 
 	g_object_class_install_properties(object_class, PROP_N, properties);
+
+	/* Signals */
+	signals[SIGNAL_SSL_FAILURE] =
+		g_signal_new("ssl-failure", G_TYPE_FROM_CLASS(class),
+			     G_SIGNAL_RUN_LAST, 0, NULL, NULL, NULL,
+			     G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_STRING);
 }
