@@ -1,14 +1,13 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2020 Arnaud Rebillout
+ * Copyright (C) 2015-2021 Arnaud Rebillout
  *
- * SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-only
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 /**
@@ -34,8 +33,8 @@
  * tags. That's all.
  */
 
-#include <glib.h>
 #include <glib-object.h>
+#include <glib.h>
 #include <gst/gst.h>
 
 #include "base/gv-base.h"
@@ -47,7 +46,7 @@
  */
 
 G_DEFINE_BOXED_TYPE(GvMetadata, gv_metadata,
-		gv_metadata_ref, gv_metadata_unref);
+		    gv_metadata_ref, gv_metadata_unref);
 
 struct _GvMetadata {
 	gchar *album;
@@ -184,9 +183,7 @@ update_date(GstTagList *taglist, const gchar *tag, gchar **out)
 	if (date) {
 		gchar *year;
 
-		year = g_date_valid(date) ?
-			g_strdup_printf("%d", g_date_get_year(date)) :
-			NULL;
+		year = g_date_valid(date) ? g_strdup_printf("%d", g_date_get_year(date)) : NULL;
 
 		if (g_strcmp0(year, *out)) {
 			g_free(*out);
@@ -230,11 +227,11 @@ gv_metadata_is_empty(GvMetadata *self)
 	g_return_val_if_fail(self != NULL, TRUE);
 
 	return self->album == NULL &&
-		self->artist == NULL &&
-		self->comment == NULL &&
-		self->genre == NULL &&
-		self->title == NULL &&
-		self->year == NULL;
+	       self->artist == NULL &&
+	       self->comment == NULL &&
+	       self->genre == NULL &&
+	       self->title == NULL &&
+	       self->year == NULL;
 }
 
 void
