@@ -1,14 +1,13 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2020 Arnaud Rebillout
+ * Copyright (C) 2015-2021 Arnaud Rebillout
  *
- * SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-only
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -38,11 +37,13 @@ G_DECLARE_FINAL_TYPE(GvPlayer, gv_player, GV, PLAYER, GObject)
 /* Data types */
 
 typedef enum {
-	GV_PLAYER_STATE_STOPPED,
-	GV_PLAYER_STATE_CONNECTING,
-	GV_PLAYER_STATE_BUFFERING,
-	GV_PLAYER_STATE_PLAYING
-} GvPlayerState;
+	GV_PLAYBACK_STATE_STOPPED,
+	GV_PLAYBACK_STATE_CONNECTING,
+	GV_PLAYBACK_STATE_BUFFERING,
+	GV_PLAYBACK_STATE_PLAYING
+} GvPlaybackState;
+
+const gchar *gv_playback_state_to_string(GvPlaybackState);
 
 /* Methods */
 
@@ -58,7 +59,7 @@ gboolean  gv_player_next  (GvPlayer *self);
 
 /* Property accessors */
 
-GvPlayerState  gv_player_get_state       (GvPlayer *self);
+GvPlaybackState  gv_player_get_playback_state       (GvPlayer *self);
 guint          gv_player_get_bitrate     (GvPlayer *self);
 GvStreaminfo  *gv_player_get_streaminfo  (GvPlayer *self);
 GvMetadata    *gv_player_get_metadata    (GvPlayer *self);
