@@ -1,14 +1,13 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2020 Arnaud Rebillout
+ * Copyright (C) 2015-2021 Arnaud Rebillout
  *
- * SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-only
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,11 +15,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
-#include <glib.h>
 #include <glib-object.h>
+#include <glib.h>
 
 #include "base/glib-object-additions.h"
 #include "base/gv-base.h"
@@ -33,6 +32,8 @@
  * Properties
  */
 
+#define DEFAULT_INSECURE FALSE
+
 enum {
 	/* Reserved */
 	PROP_0,
@@ -42,6 +43,7 @@ enum {
 	PROP_NAME,
 	PROP_URI,
 	/* Set by user - customization */
+	PROP_INSECURE,
 	PROP_USER_AGENT,
 	/* Learnt along the way */
 	PROP_STREAM_URIS,
@@ -73,12 +75,13 @@ struct _GvStationPrivate {
 	 */
 
 	/* Set at construct-time */
-	gchar  *uid;
+	gchar *uid;
 	/* Set by user - station definition */
-	gchar  *name;
-	gchar  *uri;
+	gchar *name;
+	gchar *uri;
 	/* Set by user - customization */
-	gchar  *user_agent;
+	gboolean insecure;
+	gchar *user_agent;
 	/* Learnt along the way */
 	GSList *stream_uris;
 };
@@ -105,14 +108,20 @@ copy_func_strdup(gconstpointer src, gpointer data G_GNUC_UNUSED)
 }
 
 static void
-gv_station_set_stream_uris(GvStation *self, GSList *list)
+gv_station_set_stream_uris(GvStation *self, GSList *uris)
 {
 	GvStationPrivate *priv = self->priv;
 
-	if (priv->stream_uris)
-		g_slist_free_full(priv->stream_uris, g_free);
+	if (uris == priv->stream_uris)
+		return;
 
-	priv->stream_uris = g_slist_copy_deep(list, copy_func_strdup, NULL);
+	if (priv->stream_uris) {
+		g_slist_free_full(priv->stream_uris, g_free);
+		priv->stream_uris = NULL;
+	}
+
+	if (uris)
+		priv->stream_uris = g_slist_copy_deep(uris, copy_func_strdup, NULL);
 
 	g_object_notify(G_OBJECT(self), "stream-uris");
 }
@@ -120,10 +129,15 @@ gv_station_set_stream_uris(GvStation *self, GSList *list)
 static void
 gv_station_set_stream_uri(GvStation *self, const gchar *uri)
 {
-	GSList *list = NULL;
-	list = g_slist_append(list, g_strdup(uri));
+	GSList *list;
+
+	if (uri == NULL)
+		list = NULL;
+	else
+		list = g_slist_append(NULL, (gpointer) uri);
+
 	gv_station_set_stream_uris(self, list);
-	g_slist_free_full(list, g_free);
+	g_slist_free(list);
 }
 
 /*
@@ -132,7 +146,7 @@ gv_station_set_stream_uri(GvStation *self, const gchar *uri)
 
 static void
 on_playlist_downloaded(GvPlaylist *playlist,
-                       GvStation  *self)
+		       GvStation *self)
 {
 	GSList *streams;
 
@@ -212,9 +226,14 @@ gv_station_set_uri(GvStation *self, const gchar *uri)
 	g_free(priv->uri);
 	priv->uri = g_strdup(uri);
 
-	/* If this is not a playlist uri, then it's a stream uri */
+	/* The uri either refers to a playlist, either to an audio stream.
+	 * We "guess" it right now:  if it does not seem to be a playlist,
+	 * then it's probably an audio stream, and so we save it as such.
+	 */
 	if (gv_playlist_get_format(uri) == GV_PLAYLIST_FORMAT_UNKNOWN)
 		gv_station_set_stream_uri(self, uri);
+	else
+		gv_station_set_stream_uri(self, NULL);
 
 	/* Notify */
 	g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_URI]);
@@ -228,6 +247,25 @@ gv_station_get_name_or_uri(GvStation *self)
 	return priv->name ? priv->name : priv->uri;
 }
 
+gboolean
+gv_station_get_insecure(GvStation *self)
+{
+	return self->priv->insecure;
+}
+
+void
+gv_station_set_insecure(GvStation *self, gboolean insecure)
+{
+	GvStationPrivate *priv = self->priv;
+
+	if (insecure == priv->insecure)
+		return;
+
+	priv->insecure = insecure;
+
+	g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_INSECURE]);
+}
+
 const gchar *
 gv_station_get_user_agent(GvStation *self)
 {
@@ -270,10 +308,10 @@ gv_station_get_first_stream_uri(GvStation *self)
 }
 
 static void
-gv_station_get_property(GObject    *object,
-                        guint       property_id,
-                        GValue     *value G_GNUC_UNUSED,
-                        GParamSpec *pspec)
+gv_station_get_property(GObject *object,
+			guint property_id,
+			GValue *value G_GNUC_UNUSED,
+			GParamSpec *pspec)
 {
 	GvStation *self = GV_STATION(object);
 
@@ -289,6 +327,9 @@ gv_station_get_property(GObject    *object,
 	case PROP_URI:
 		g_value_set_string(value, gv_station_get_uri(self));
 		break;
+	case PROP_INSECURE:
+		g_value_set_boolean(value, gv_station_get_insecure(self));
+		break;
 	case PROP_USER_AGENT:
 		g_value_set_string(value, gv_station_get_user_agent(self));
 		break;
@@ -302,10 +343,10 @@ gv_station_get_property(GObject    *object,
 }
 
 static void
-gv_station_set_property(GObject      *object,
-                        guint         property_id,
-                        const GValue *value,
-                        GParamSpec   *pspec)
+gv_station_set_property(GObject *object,
+			guint property_id,
+			const GValue *value,
+			GParamSpec *pspec)
 {
 	GvStation *self = GV_STATION(object);
 
@@ -318,6 +359,9 @@ gv_station_set_property(GObject      *object,
 	case PROP_URI:
 		gv_station_set_uri(self, g_value_get_string(value));
 		break;
+	case PROP_INSECURE:
+		gv_station_set_insecure(self, g_value_get_boolean(value));
+		break;
 	case PROP_USER_AGENT:
 		gv_station_set_user_agent(self, g_value_get_string(value));
 		break;
@@ -350,7 +394,8 @@ gv_station_download_playlist(GvStation *self)
 	/* No need to keep track of that, it's unreferenced in the callback */
 	playlist = gv_playlist_new(priv->uri);
 	g_signal_connect_object(playlist, "downloaded", G_CALLBACK(on_playlist_downloaded), self, 0);
-	gv_playlist_download(playlist, priv->user_agent ? priv->user_agent : gv_core_user_agent);
+	gv_playlist_download(playlist, priv->insecure,
+			     priv->user_agent ? priv->user_agent : gv_core_user_agent);
 
 	return TRUE;
 }
@@ -375,9 +420,9 @@ GvStation *
 gv_station_new(const gchar *name, const gchar *uri)
 {
 	return g_object_new(GV_TYPE_STATION,
-	                    "name", name,
-	                    "uri", uri,
-	                    NULL);
+			    "name", name,
+			    "uri", uri,
+			    NULL);
 }
 
 /*
@@ -404,6 +449,22 @@ gv_station_finalize(GObject *object)
 	G_OBJECT_CHAINUP_FINALIZE(gv_station, object);
 }
 
+static void
+gv_station_constructed(GObject *object)
+{
+	GvStation *self = GV_STATION(object);
+	GvStationPrivate *priv = self->priv;
+
+	TRACE("%p", object);
+
+	/* Initialize properties */
+	priv->uid = g_strdup_printf("%p", self);
+	priv->insecure = DEFAULT_INSECURE;
+
+	/* Chain up */
+	G_OBJECT_CHAINUP_CONSTRUCTED(gv_station, object);
+}
+
 static void
 gv_station_init(GvStation *self)
 {
@@ -411,9 +472,6 @@ gv_station_init(GvStation *self)
 
 	/* Initialize private pointer */
 	self->priv = gv_station_get_instance_private(self);
-
-	/* Initialize properties */
-	self->priv->uid = g_strdup_printf("%p", self);
 }
 
 static void
@@ -425,36 +483,42 @@ gv_station_class_init(GvStationClass *class)
 
 	/* Override GObject methods */
 	object_class->finalize = gv_station_finalize;
+	object_class->constructed = gv_station_constructed;
 
 	/* Properties */
 	object_class->get_property = gv_station_get_property;
 	object_class->set_property = gv_station_set_property;
 
 	properties[PROP_UID] =
-	        g_param_spec_string("uid", "UID", NULL, NULL,
-	                            GV_PARAM_READABLE);
+		g_param_spec_string("uid", "UID", NULL, NULL,
+				    GV_PARAM_READABLE);
 
 	properties[PROP_NAME] =
-	        g_param_spec_string("name", "Name", NULL, NULL,
-	                            GV_PARAM_READWRITE | G_PARAM_CONSTRUCT);
+		g_param_spec_string("name", "Name", NULL, NULL,
+				    GV_PARAM_READWRITE | G_PARAM_CONSTRUCT);
 
 	properties[PROP_URI] =
-	        g_param_spec_string("uri", "Uri", NULL, NULL,
-	                            GV_PARAM_READWRITE | G_PARAM_CONSTRUCT);
+		g_param_spec_string("uri", "Uri", NULL, NULL,
+				    GV_PARAM_READWRITE | G_PARAM_CONSTRUCT);
+
+	properties[PROP_INSECURE] =
+		g_param_spec_boolean("insecure", "Insecure", NULL,
+				     DEFAULT_INSECURE,
+				     GV_PARAM_READWRITE);
 
 	properties[PROP_USER_AGENT] =
-	        g_param_spec_string("user-agent", "User agent", NULL, NULL,
-	                            GV_PARAM_READWRITE);
+		g_param_spec_string("user-agent", "User agent", NULL, NULL,
+				    GV_PARAM_READWRITE);
 
 	properties[PROP_STREAM_URIS] =
-	        g_param_spec_pointer("stream-uris", "Stream uris", NULL,
-	                             GV_PARAM_READABLE);
+		g_param_spec_pointer("stream-uris", "Stream uris", NULL,
+				     GV_PARAM_READABLE);
 
 	g_object_class_install_properties(object_class, PROP_N, properties);
 
 	/* Signals */
 	signals[SIGNAL_PLAYLIST_DOWNLOADED] =
-	        g_signal_new("playlist-downloaded", G_TYPE_FROM_CLASS(class),
-	                     G_SIGNAL_RUN_LAST, 0, NULL, NULL, NULL,
+		g_signal_new("playlist-downloaded", G_TYPE_FROM_CLASS(class),
+			     G_SIGNAL_RUN_LAST, 0, NULL, NULL, NULL,
 			     G_TYPE_NONE, 0);
 }
