@@ -1,14 +1,13 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2020 Arnaud Rebillout
+ * Copyright (C) 2015-2021 Arnaud Rebillout
  *
- * SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-only
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,14 +15,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdio.h>
 #include <unistd.h>
 
-#include <glib.h>
 #include <glib-object.h>
+#include <glib.h>
 
 #include "base/glib-additions.h"
 #include "base/gv-base.h"
@@ -46,7 +45,7 @@ G_DEFINE_TYPE(GvConsoleOutput, gv_console_output, GV_TYPE_FEATURE)
  * Helpers
  */
 
-#define PRINT(fmt, ...)    g_print(fmt "\n", ##__VA_ARGS__)
+#define PRINT(fmt, ...) g_print(fmt "\n", ##__VA_ARGS__)
 
 static const gchar *
 time_now(void)
@@ -143,18 +142,18 @@ print_metadata(GvMetadata *metadata)
  */
 
 static void
-on_player_notify(GvPlayer        *player,
-                 GParamSpec       *pspec,
-                 GvConsoleOutput *self G_GNUC_UNUSED)
+on_player_notify(GvPlayer *player,
+		 GParamSpec *pspec,
+		 GvConsoleOutput *self G_GNUC_UNUSED)
 {
 	const gchar *property_name = g_param_spec_get_name(pspec);
 
-	if (!g_strcmp0(property_name, "state")) {
-		GvPlayerState state;
+	if (!g_strcmp0(property_name, "playback-state")) {
+		GvPlaybackState state;
 
-		state = gv_player_get_state(player);
+		state = gv_player_get_playback_state(player);
 
-		if (state == GV_PLAYER_STATE_PLAYING) {
+		if (state == GV_PLAYBACK_STATE_PLAYING) {
 			GvStation *station;
 
 			station = gv_player_get_station(player);
@@ -170,7 +169,7 @@ on_player_notify(GvPlayer        *player,
 
 static void
 on_errorable_error(GvErrorable *errorable G_GNUC_UNUSED, const gchar *error_string,
-                   GvConsoleOutput *self G_GNUC_UNUSED)
+		   GvConsoleOutput *self G_GNUC_UNUSED)
 {
 	print_error(error_string);
 }
