@@ -1,14 +1,13 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2020 Arnaud Rebillout
+ * Copyright (C) 2015-2021 Arnaud Rebillout
  *
- * SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-only
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,15 +15,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
-#include <string.h>
 #include <math.h>
+#include <string.h>
 
-#include <glib.h>
 #include <gio/gio.h>
 #include <glib-object.h>
+#include <glib.h>
 
 #include "base/glib-additions.h"
 #include "base/glib-object-additions.h"
@@ -34,122 +33,122 @@
 #include "ui/gv-ui.h"
 #endif
 
-#include "feat/gv-dbus-server.h"
 #include "feat/gv-dbus-server-mpris2.h"
+#include "feat/gv-dbus-server.h"
 
-#define TRACKID_PATH         GV_APPLICATION_PATH "/TrackList"
-#define PLAYLISTID_PATH      GV_APPLICATION_PATH "/Playlist"
+#define TRACKID_PATH	GV_APPLICATION_PATH "/TrackList"
+#define PLAYLISTID_PATH GV_APPLICATION_PATH "/Playlist"
 
-#define DBUS_NAME            "org.mpris.MediaPlayer2." GV_NAME_CAPITAL
-#define DBUS_PATH            "/org/mpris/MediaPlayer2"
-#define DBUS_IFACE_ROOT      "org.mpris.MediaPlayer2"
+#define DBUS_NAME	     "org.mpris.MediaPlayer2." GV_NAME_CAPITAL
+#define DBUS_PATH	     "/org/mpris/MediaPlayer2"
+#define DBUS_IFACE_ROOT	     "org.mpris.MediaPlayer2"
 #define DBUS_IFACE_PLAYER    DBUS_IFACE_ROOT ".Player"
 #define DBUS_IFACE_TRACKLIST DBUS_IFACE_ROOT ".TrackList"
 #define DBUS_IFACE_PLAYLISTS DBUS_IFACE_ROOT ".Playlists"
 
 static const gchar *DBUS_INTROSPECTION =
-        "<node>"
-        "    <interface name='"DBUS_IFACE_ROOT"'>"
-        "        <method name='Raise'/>"
-        "        <method name='Quit'/>"
-        "        <property name='CanRaise'            type='b'  access='read'/>"
-        "        <property name='CanQuit'             type='b'  access='read'/>"
-        "        <property name='Fullscreen'          type='b'  access='readwrite'/>"
-        "        <property name='CanSetFullscreen'    type='b'  access='read'/>"
-        "        <property name='HasTrackList'        type='b'  access='read'/>"
-        "        <property name='Identity'            type='s'  access='read'/>"
-        "        <property name='DesktopEntry'        type='s'  access='read'/>"
-        "        <property name='SupportedUriSchemes' type='as' access='read'/>"
-        "        <property name='SupportedMimeTypes'  type='as' access='read'/>"
-        "    </interface>"
-        "    <interface name='"DBUS_IFACE_PLAYER"'>"
-        "        <method name='Play'/>"
-        "        <method name='Pause'/>"
-        "        <method name='PlayPause'/>"
-        "        <method name='Stop'/>"
-        "        <method name='Next'/>"
-        "        <method name='Previous'/>"
-        "        <method name='Seek'>"
-        "            <arg direction='in' name='Offset' type='x'/>"
-        "        </method>"
-        "        <method name='SetPosition'>"
-        "            <arg direction='in' name='TrackId'  type='o'/>"
-        "            <arg direction='in' name='Position' type='x'/>"
-        "        </method>"
-        "        <method name='OpenUri'>"
-        "            <arg direction='in' name='Uri' type='s'/>"
-        "        </method>"
-        "        <signal name='Seeked'>"
-        "            <arg name='Position' type='x'/>"
-        "        </signal>"
-        "        <property name='PlaybackStatus' type='s'     access='read'/>"
-        "        <property name='LoopStatus'     type='s'     access='readwrite'/>"
-        "        <property name='Shuffle'        type='b'     access='readwrite'/>"
-        "        <property name='Volume'         type='d'     access='readwrite'/>"
-        "        <property name='Rate'           type='d'     access='readwrite'/>"
-        "        <property name='MinimumRate'    type='d'     access='read'/>"
-        "        <property name='MaximumRate'    type='d'     access='read'/>"
-        "        <property name='Metadata'       type='a{sv}' access='read'/>"
-        "        <property name='CanPlay'        type='b'     access='read'/>"
-        "        <property name='CanPause'       type='b'     access='read'/>"
-        "        <property name='CanGoNext'      type='b'     access='read'/>"
-        "        <property name='CanGoPrevious'  type='b'     access='read'/>"
-        "        <property name='CanSeek'        type='b'     access='read'/>"
-        "        <property name='CanControl'     type='b'     access='read'/>"
-        "    </interface>"
-        "    <interface name='"DBUS_IFACE_TRACKLIST"'>"
-        "        <method name='GetTracksMetadata'>"
-        "            <arg direction='in'  name='TrackIds'     type='ao'/>"
-        "            <arg direction='out' name='Metadata'     type='aa{sv}'/>"
-        "        </method>"
-        "        <method name='AddTrack'>"
-        "            <arg direction='in'  name='Uri'          type='s'/>"
-        "            <arg direction='in'  name='AfterTrack'   type='o'/>"
-        "            <arg direction='in'  name='SetAsCurrent' type='b'/>"
-        "        </method>"
-        "        <method name='RemoveTrack'>"
-        "            <arg direction='in'  name='TrackId'      type='o'/>"
-        "        </method>"
-        "        <method name='GoTo'>"
-        "            <arg direction='in'  name='TrackId'      type='o'/>"
-        "        </method>"
-        "        <signal name='TrackListReplaced'>"
-        "            <arg name='Tracks'       type='ao'/>"
-        "            <arg name='CurrentTrack' type='o'/>"
-        "        </signal>"
-        "        <signal name='TrackAdded'>"
-        "            <arg name='Metadata'     type='a{sv}'/>"
-        "            <arg name='AfterTrack'   type='o'/>"
-        "        </signal>"
-        "        <signal name='TrackRemoved'>"
-        "            <arg name='TrackId'      type='o'/>"
-        "        </signal>"
-        "        <signal name='TrackMetadataChanged'>"
-        "            <arg name='TrackId'      type='o'/>"
-        "            <arg name='Metadata'     type='a{sv}'/>"
-        "        </signal>"
-        "        <property name='Tracks'        type='ao' access='read'/>"
-        "        <property name='CanEditTracks' type='b'  access='read'/>"
-        "    </interface>"
-        "    <interface name='"DBUS_IFACE_PLAYLISTS"'>"
-        "        <method name='ActivatePlaylist'>"
-        "            <arg direction='in'  name='PlaylistId'   type='o'/>"
-        "        </method>"
-        "        <method name='GetPlaylists'>"
-        "            <arg direction='in'  name='Index'        type='u'/>"
-        "            <arg direction='in'  name='MaxCount'     type='u'/>"
-        "            <arg direction='in'  name='Order'        type='s'/>"
-        "            <arg direction='in'  name='ReverseOrder' type='b'/>"
-        "            <arg direction='out' name='Playlists'    type='a(oss)'/>"
-        "        </method>"
-        "        <signal name='PlaylistChanged'>"
-        "            <arg name='Playlist' type='(oss)'/>"
-        "        </signal>"
-        "        <property name='PlaylistCount'  type='u'        access='read'/>"
-        "        <property name='Orderings'      type='as'       access='read'/>"
-        "        <property name='ActivePlaylist' type='(b(oss))' access='read'/>"
-        "    </interface>"
-        "</node>";
+	"<node>"
+	"    <interface name='" DBUS_IFACE_ROOT "'>"
+	"        <method name='Raise'/>"
+	"        <method name='Quit'/>"
+	"        <property name='CanRaise'            type='b'  access='read'/>"
+	"        <property name='CanQuit'             type='b'  access='read'/>"
+	"        <property name='Fullscreen'          type='b'  access='readwrite'/>"
+	"        <property name='CanSetFullscreen'    type='b'  access='read'/>"
+	"        <property name='HasTrackList'        type='b'  access='read'/>"
+	"        <property name='Identity'            type='s'  access='read'/>"
+	"        <property name='DesktopEntry'        type='s'  access='read'/>"
+	"        <property name='SupportedUriSchemes' type='as' access='read'/>"
+	"        <property name='SupportedMimeTypes'  type='as' access='read'/>"
+	"    </interface>"
+	"    <interface name='" DBUS_IFACE_PLAYER "'>"
+	"        <method name='Play'/>"
+	"        <method name='Pause'/>"
+	"        <method name='PlayPause'/>"
+	"        <method name='Stop'/>"
+	"        <method name='Next'/>"
+	"        <method name='Previous'/>"
+	"        <method name='Seek'>"
+	"            <arg direction='in' name='Offset' type='x'/>"
+	"        </method>"
+	"        <method name='SetPosition'>"
+	"            <arg direction='in' name='TrackId'  type='o'/>"
+	"            <arg direction='in' name='Position' type='x'/>"
+	"        </method>"
+	"        <method name='OpenUri'>"
+	"            <arg direction='in' name='Uri' type='s'/>"
+	"        </method>"
+	"        <signal name='Seeked'>"
+	"            <arg name='Position' type='x'/>"
+	"        </signal>"
+	"        <property name='PlaybackStatus' type='s'     access='read'/>"
+	"        <property name='LoopStatus'     type='s'     access='readwrite'/>"
+	"        <property name='Shuffle'        type='b'     access='readwrite'/>"
+	"        <property name='Volume'         type='d'     access='readwrite'/>"
+	"        <property name='Rate'           type='d'     access='readwrite'/>"
+	"        <property name='MinimumRate'    type='d'     access='read'/>"
+	"        <property name='MaximumRate'    type='d'     access='read'/>"
+	"        <property name='Metadata'       type='a{sv}' access='read'/>"
+	"        <property name='CanPlay'        type='b'     access='read'/>"
+	"        <property name='CanPause'       type='b'     access='read'/>"
+	"        <property name='CanGoNext'      type='b'     access='read'/>"
+	"        <property name='CanGoPrevious'  type='b'     access='read'/>"
+	"        <property name='CanSeek'        type='b'     access='read'/>"
+	"        <property name='CanControl'     type='b'     access='read'/>"
+	"    </interface>"
+	"    <interface name='" DBUS_IFACE_TRACKLIST "'>"
+	"        <method name='GetTracksMetadata'>"
+	"            <arg direction='in'  name='TrackIds'     type='ao'/>"
+	"            <arg direction='out' name='Metadata'     type='aa{sv}'/>"
+	"        </method>"
+	"        <method name='AddTrack'>"
+	"            <arg direction='in'  name='Uri'          type='s'/>"
+	"            <arg direction='in'  name='AfterTrack'   type='o'/>"
+	"            <arg direction='in'  name='SetAsCurrent' type='b'/>"
+	"        </method>"
+	"        <method name='RemoveTrack'>"
+	"            <arg direction='in'  name='TrackId'      type='o'/>"
+	"        </method>"
+	"        <method name='GoTo'>"
+	"            <arg direction='in'  name='TrackId'      type='o'/>"
+	"        </method>"
+	"        <signal name='TrackListReplaced'>"
+	"            <arg name='Tracks'       type='ao'/>"
+	"            <arg name='CurrentTrack' type='o'/>"
+	"        </signal>"
+	"        <signal name='TrackAdded'>"
+	"            <arg name='Metadata'     type='a{sv}'/>"
+	"            <arg name='AfterTrack'   type='o'/>"
+	"        </signal>"
+	"        <signal name='TrackRemoved'>"
+	"            <arg name='TrackId'      type='o'/>"
+	"        </signal>"
+	"        <signal name='TrackMetadataChanged'>"
+	"            <arg name='TrackId'      type='o'/>"
+	"            <arg name='Metadata'     type='a{sv}'/>"
+	"        </signal>"
+	"        <property name='Tracks'        type='ao' access='read'/>"
+	"        <property name='CanEditTracks' type='b'  access='read'/>"
+	"    </interface>"
+	"    <interface name='" DBUS_IFACE_PLAYLISTS "'>"
+	"        <method name='ActivatePlaylist'>"
+	"            <arg direction='in'  name='PlaylistId'   type='o'/>"
+	"        </method>"
+	"        <method name='GetPlaylists'>"
+	"            <arg direction='in'  name='Index'        type='u'/>"
+	"            <arg direction='in'  name='MaxCount'     type='u'/>"
+	"            <arg direction='in'  name='Order'        type='s'/>"
+	"            <arg direction='in'  name='ReverseOrder' type='b'/>"
+	"            <arg direction='out' name='Playlists'    type='a(oss)'/>"
+	"        </method>"
+	"        <signal name='PlaylistChanged'>"
+	"            <arg name='Playlist' type='(oss)'/>"
+	"        </signal>"
+	"        <property name='PlaylistCount'  type='u'        access='read'/>"
+	"        <property name='Orderings'      type='as'       access='read'/>"
+	"        <property name='ActivePlaylist' type='(b(oss))' access='read'/>"
+	"    </interface>"
+	"</node>";
 
 /*
  * GObject definitions
@@ -180,9 +179,9 @@ make_playlist_id(GvStation *station)
 }
 
 static gboolean
-parse_playlist_id(const gchar    *playlist_id,
-                  GvStationList  *station_list,
-                  GvStation     **station)
+parse_playlist_id(const gchar *playlist_id,
+		  GvStationList *station_list,
+		  GvStation **station)
 {
 	const gchar *station_uid;
 
@@ -213,9 +212,9 @@ make_track_id(GvStation *station)
 }
 
 static gboolean
-parse_track_id(const gchar     *track_id,
-               GvStationList  *station_list,
-               GvStation     **station)
+parse_track_id(const gchar *track_id,
+	       GvStationList *station_list,
+	       GvStation **station)
 {
 	const gchar *station_uid;
 
@@ -247,7 +246,7 @@ compare_alphabetically(GvStation *a, GvStation *b)
 
 static GList *
 build_station_list(GvStationList *station_list, gboolean alphabetical,
-                   gboolean reverse, guint start_index, guint max_count)
+		   gboolean reverse, guint start_index, guint max_count)
 {
 	GvStationListIter *iter;
 	GvStation *station;
@@ -341,8 +340,8 @@ g_variant_new_metadata_map(GvStation *station, GvMetadata *metadata)
 {
 	GVariantBuilder b;
 	gchar *track_id;
-	const gchar *uri;
-	const gchar *name;
+	const gchar *station_uri;
+	const gchar *station_name;
 	const gchar *artist;
 	const gchar *title;
 	const gchar *album;
@@ -360,21 +359,37 @@ g_variant_new_metadata_map(GvStation *station, GvMetadata *metadata)
 	g_variant_builder_add_dictentry_object_path(&b, "mpris:trackid", track_id);
 	g_free(track_id);
 
-	name = gv_station_get_name(station);
-	if (name)
-		g_variant_builder_add_dictentry_string(&b, "goodvibes:station", name);
+	station_uri = gv_station_get_uri(station);
+	if (station_uri)
+		g_variant_builder_add_dictentry_string(&b, "xesam:url", station_uri);
 
-	uri = gv_station_get_uri(station);
-	if (uri)
-		g_variant_builder_add_dictentry_string(&b, "xesam:url", uri);
+	/* In the MPRIS2 spec, there's no room for a radio station name. So we set it
+	 * in the non-standard field 'goodvibes:station', in case someone cares.
+	 */
+	station_name = gv_station_get_name(station);
+	if (station_name)
+		g_variant_builder_add_dictentry_string(&b, "goodvibes:station", station_name);
 
-	/* Metadata if any */
-	if (metadata == NULL)
+	/* If no metadata, set the station name as the artist. */
+	if (metadata == NULL) {
+		if (station_name) {
+			g_variant_builder_add_dictentry_array_string(&b, "xesam:artist", station_name, NULL);
+			g_variant_builder_add_dictentry_array_string(&b, "xesam:albumArtist", station_name, NULL);
+		}
 		goto end;
+	}
 
+	/* In practice, very often for radios, only the 'title' metadata is set.
+	 * So let's recycle the unused 'artist' field for the stations name.
+	 */
 	artist = gv_metadata_get_artist(metadata);
-	if (artist)
+	if (artist) {
 		g_variant_builder_add_dictentry_array_string(&b, "xesam:artist", artist, NULL);
+		g_variant_builder_add_dictentry_array_string(&b, "xesam:albumArtist", artist, NULL);
+	} else if (station_name) {
+		g_variant_builder_add_dictentry_array_string(&b, "xesam:artist", station_name, NULL);
+		g_variant_builder_add_dictentry_array_string(&b, "xesam:albumArtist", station_name, NULL);
+	}
 
 	title = gv_metadata_get_title(metadata);
 	if (title)
@@ -403,13 +418,13 @@ end:
 static GVariant *
 g_variant_new_playback_status(GvPlayer *player)
 {
-	GvPlayerState state;
+	GvPlaybackState state;
 	gchar *state_str;
 
-	state = gv_player_get_state(player);
+	state = gv_player_get_playback_state(player);
 
 	switch (state) {
-	case GV_PLAYER_STATE_STOPPED:
+	case GV_PLAYBACK_STATE_STOPPED:
 		state_str = "Stopped";
 		break;
 	default:
@@ -479,9 +494,9 @@ g_variant_new_can_go_next(GvPlayer *player)
  */
 
 static GVariant *
-method_raise(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-             GVariant       *params G_GNUC_UNUSED,
-             GError        **err G_GNUC_UNUSED)
+method_raise(GvDbusServer *dbus_server G_GNUC_UNUSED,
+	     GVariant *params G_GNUC_UNUSED,
+	     GError **err G_GNUC_UNUSED)
 {
 #ifdef GV_UI_ENABLED
 	gv_ui_present_main();
@@ -490,9 +505,9 @@ method_raise(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 }
 
 static GVariant *
-method_quit(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-            GVariant       *params G_GNUC_UNUSED,
-            GError        **err G_GNUC_UNUSED)
+method_quit(GvDbusServer *dbus_server G_GNUC_UNUSED,
+	    GVariant *params G_GNUC_UNUSED,
+	    GError **err G_GNUC_UNUSED)
 {
 	gv_core_quit();
 
@@ -500,15 +515,17 @@ method_quit(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 }
 
 static GvDbusMethod root_methods[] = {
+	// clang-format off
 	{ "Raise", method_raise },
 	{ "Quit",  method_quit  },
 	{ NULL,    NULL         }
+	// clang-format on
 };
 
 static GVariant *
-method_play(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-            GVariant       *params G_GNUC_UNUSED,
-            GError        **err G_GNUC_UNUSED)
+method_play(GvDbusServer *dbus_server G_GNUC_UNUSED,
+	    GVariant *params G_GNUC_UNUSED,
+	    GError **err G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
 
@@ -518,9 +535,9 @@ method_play(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 }
 
 static GVariant *
-method_stop(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-            GVariant       *params G_GNUC_UNUSED,
-            GError        **err G_GNUC_UNUSED)
+method_stop(GvDbusServer *dbus_server G_GNUC_UNUSED,
+	    GVariant *params G_GNUC_UNUSED,
+	    GError **err G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
 
@@ -530,9 +547,9 @@ method_stop(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 }
 
 static GVariant *
-method_toggle(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-              GVariant       *params G_GNUC_UNUSED,
-              GError        **err G_GNUC_UNUSED)
+method_toggle(GvDbusServer *dbus_server G_GNUC_UNUSED,
+	      GVariant *params G_GNUC_UNUSED,
+	      GError **err G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
 
@@ -542,9 +559,9 @@ method_toggle(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 }
 
 static GVariant *
-method_next(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-            GVariant       *params G_GNUC_UNUSED,
-            GError        **err G_GNUC_UNUSED)
+method_next(GvDbusServer *dbus_server G_GNUC_UNUSED,
+	    GVariant *params G_GNUC_UNUSED,
+	    GError **err G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
 
@@ -555,9 +572,9 @@ method_next(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 }
 
 static GVariant *
-method_prev(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-            GVariant       *params G_GNUC_UNUSED,
-            GError        **err G_GNUC_UNUSED)
+method_prev(GvDbusServer *dbus_server G_GNUC_UNUSED,
+	    GVariant *params G_GNUC_UNUSED,
+	    GError **err G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
 
@@ -568,11 +585,11 @@ method_prev(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 }
 
 static GVariant *
-method_open_uri(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-                GVariant       *params G_GNUC_UNUSED,
-                GError        **err)
+method_open_uri(GvDbusServer *dbus_server G_GNUC_UNUSED,
+		GVariant *params G_GNUC_UNUSED,
+		GError **err)
 {
-	GvPlayer *player  = gv_core_player;
+	GvPlayer *player = gv_core_player;
 	GvStationList *station_list = gv_core_station_list;
 	GvStation *station;
 	const gchar *uri;
@@ -582,7 +599,7 @@ method_open_uri(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 	/* Ensure URI is valid */
 	if (!is_uri_scheme_supported(uri)) {
 		g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
-		            "URI scheme not supported.");
+			    "URI scheme not supported.");
 		return NULL;
 	}
 
@@ -603,6 +620,7 @@ method_open_uri(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 }
 
 static GvDbusMethod player_methods[] = {
+	// clang-format off
 	{ "Play",        method_play     },
 	{ "Pause",       method_stop     },
 	{ "PlayPause",   method_toggle   },
@@ -613,12 +631,13 @@ static GvDbusMethod player_methods[] = {
 	{ "SetPosition", NULL            },
 	{ "OpenUri",     method_open_uri },
 	{ NULL,          NULL            }
+	// clang-format on
 };
 
 static GVariant *
-method_get_tracks_metadata(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-                           GVariant       *params,
-                           GError        **err G_GNUC_UNUSED)
+method_get_tracks_metadata(GvDbusServer *dbus_server G_GNUC_UNUSED,
+			   GVariant *params,
+			   GError **err G_GNUC_UNUSED)
 {
 	GvStationList *station_list = gv_core_station_list;
 	GVariantBuilder b;
@@ -641,9 +660,9 @@ method_get_tracks_metadata(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 }
 
 static GVariant *
-method_add_track(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-                 GVariant       *params,
-                 GError        **err)
+method_add_track(GvDbusServer *dbus_server G_GNUC_UNUSED,
+		 GVariant *params,
+		 GError **err)
 {
 	GvPlayer *player = gv_core_player;
 	GvStationList *station_list = gv_core_station_list;
@@ -657,14 +676,14 @@ method_add_track(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 	/* Ensure URI is valid */
 	if (!is_uri_scheme_supported(uri)) {
 		g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
-		            "Invalid URI scheme for param 'Uri'.");
+			    "Invalid URI scheme for param 'Uri'.");
 		return NULL;
 	}
 
 	/* Handle 'after_track' */
 	if (!parse_track_id(after_track_id, station_list, &after_station)) {
 		g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
-		            "Invalid param 'AfterTrack'.");
+			    "Invalid param 'AfterTrack'.");
 		return NULL;
 	}
 
@@ -681,7 +700,7 @@ method_add_track(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 	/* Play new station if needed */
 	if (set_as_current) {
 		gv_player_set_station(player, station);
-		if (gv_player_get_state(player) != GV_PLAYER_STATE_STOPPED)
+		if (gv_player_get_playback_state(player) != GV_PLAYBACK_STATE_STOPPED)
 			gv_player_play(player);
 	}
 
@@ -689,9 +708,9 @@ method_add_track(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 }
 
 static GVariant *
-method_remove_track(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-                    GVariant       *params,
-                    GError        **err)
+method_remove_track(GvDbusServer *dbus_server G_GNUC_UNUSED,
+		    GVariant *params,
+		    GError **err)
 {
 	GvStationList *station_list = gv_core_station_list;
 	const gchar *track_id;
@@ -700,7 +719,7 @@ method_remove_track(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 	g_variant_get(params, "(&o)", &track_id);
 	if (!parse_track_id(track_id, station_list, &station)) {
 		g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
-		            "Invalid param 'TrackId'.");
+			    "Invalid param 'TrackId'.");
 		return NULL;
 	}
 
@@ -710,9 +729,9 @@ method_remove_track(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 }
 
 static GVariant *
-method_go_to(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-             GVariant       *params,
-             GError        **err)
+method_go_to(GvDbusServer *dbus_server G_GNUC_UNUSED,
+	     GVariant *params,
+	     GError **err)
 {
 	GvPlayer *player = gv_core_player;
 	GvStationList *station_list = gv_core_station_list;
@@ -724,30 +743,32 @@ method_go_to(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 	g_variant_get(params, "(&o)", &track_id);
 	if (!parse_track_id(track_id, station_list, &station)) {
 		g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
-		            "Invalid param 'TrackId'.");
+			    "Invalid param 'TrackId'.");
 		return NULL;
 	}
 
 	gv_player_set_station(player, station);
 
-	if (gv_player_get_state(player) != GV_PLAYER_STATE_STOPPED)
+	if (gv_player_get_playback_state(player) != GV_PLAYBACK_STATE_STOPPED)
 		gv_player_play(player);
 
 	return NULL;
 }
 
 static GvDbusMethod tracklist_methods[] = {
+	// clang-format off
 	{ "GetTracksMetadata", method_get_tracks_metadata },
 	{ "AddTrack",          method_add_track           },
 	{ "RemoveTrack",       method_remove_track        },
 	{ "GoTo",              method_go_to               },
 	{ NULL,                NULL                       }
+	// clang-format on
 };
 
 static GVariant *
-method_activate_playlist(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-                         GVariant      *params,
-                         GError       **err)
+method_activate_playlist(GvDbusServer *dbus_server G_GNUC_UNUSED,
+			 GVariant *params,
+			 GError **err)
 {
 	GvPlayer *player = gv_core_player;
 	GvStationList *station_list = gv_core_station_list;
@@ -758,7 +779,7 @@ method_activate_playlist(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 
 	if (!parse_playlist_id(playlist_id, station_list, &station)) {
 		g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
-		            "Invalid param 'PlaylistId'.");
+			    "Invalid param 'PlaylistId'.");
 		return NULL;
 	}
 
@@ -772,9 +793,9 @@ method_activate_playlist(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 }
 
 static GVariant *
-method_get_playlists(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-                     GVariant      *params,
-                     GError       **err G_GNUC_UNUSED)
+method_get_playlists(GvDbusServer *dbus_server G_GNUC_UNUSED,
+		     GVariant *params,
+		     GError **err G_GNUC_UNUSED)
 {
 	GvStationList *station_list = gv_core_station_list;
 	GVariantBuilder b;
@@ -794,7 +815,7 @@ method_get_playlists(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 
 	/* Make a list */
 	list = build_station_list(station_list, alphabetical, reverse_order,
-	                          start_index, max_count);
+				  start_index, max_count);
 
 	/* Make a GVariant */
 	g_variant_builder_init(&b, G_VARIANT_TYPE("a(oss)"));
@@ -812,9 +833,11 @@ method_get_playlists(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 }
 
 static GvDbusMethod playlists_methods[] = {
+	// clang-format off
 	{ "ActivatePlaylist",  method_activate_playlist },
 	{ "GetPlaylists",      method_get_playlists     },
 	{ NULL,                NULL                     }
+	// clang-format on
 };
 
 /*
@@ -836,12 +859,12 @@ prop_get_false(GvDbusServer *dbus_server G_GNUC_UNUSED)
 }
 
 static gboolean
-prop_set_error(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-               GVariant       *value G_GNUC_UNUSED,
-               GError        **err)
+prop_set_error(GvDbusServer *dbus_server G_GNUC_UNUSED,
+	       GVariant *value G_GNUC_UNUSED,
+	       GError **err)
 {
 	g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_NOT_SUPPORTED,
-	            "Setting this property is not supported.");
+		    "Setting this property is not supported.");
 
 	return FALSE;
 }
@@ -881,6 +904,7 @@ prop_get_supported_mime_types(GvDbusServer *dbus_server G_GNUC_UNUSED)
 }
 
 static GvDbusProperty root_properties[] = {
+	// clang-format off
 	{ "CanRaise",            prop_get_can_raise,             NULL },
 	{ "CanQuit",             prop_get_true,                  NULL },
 	{ "Fullscreen",          prop_get_false,                 prop_set_error },
@@ -891,6 +915,7 @@ static GvDbusProperty root_properties[] = {
 	{ "SupportedUriSchemes", prop_get_supported_uri_schemes, NULL },
 	{ "SupportedMimeTypes",  prop_get_supported_mime_types,  NULL },
 	{ NULL,                  NULL,                           NULL }
+	// clang-format on
 };
 
 static GVariant *
@@ -910,9 +935,9 @@ prop_get_loop_status(GvDbusServer *dbus_server G_GNUC_UNUSED)
 }
 
 static gboolean
-prop_set_loop_status(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-                     GVariant       *value,
-                     GError        **err)
+prop_set_loop_status(GvDbusServer *dbus_server G_GNUC_UNUSED,
+		     GVariant *value,
+		     GError **err)
 {
 	GvPlayer *player = gv_core_player;
 	const gchar *loop_status;
@@ -931,7 +956,7 @@ prop_set_loop_status(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 	} else {
 		/* Any other value should raise an error */
 		g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
-		            "Invalid value.");
+			    "Invalid value.");
 
 		return FALSE;
 	}
@@ -950,9 +975,9 @@ prop_get_shuffle(GvDbusServer *dbus_server G_GNUC_UNUSED)
 }
 
 static gboolean
-prop_set_shuffle(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-                 GVariant       *value,
-                 GError        **err G_GNUC_UNUSED)
+prop_set_shuffle(GvDbusServer *dbus_server G_GNUC_UNUSED,
+		 GVariant *value,
+		 GError **err G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
 	gboolean shuffle;
@@ -972,9 +997,9 @@ prop_get_volume(GvDbusServer *dbus_server G_GNUC_UNUSED)
 }
 
 static gboolean
-prop_set_volume(GvDbusServer  *dbus_server G_GNUC_UNUSED,
-                GVariant       *value,
-                GError        **err G_GNUC_UNUSED)
+prop_set_volume(GvDbusServer *dbus_server G_GNUC_UNUSED,
+		GVariant *value,
+		GError **err G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
 	gdouble volume;
@@ -1030,6 +1055,7 @@ prop_get_can_go_next(GvDbusServer *dbus_server G_GNUC_UNUSED)
 }
 
 static GvDbusProperty player_properties[] = {
+	// clang-format off
 	{ "PlaybackStatus", prop_get_playback_status, NULL },
 	{ "LoopStatus",     prop_get_loop_status,     prop_set_loop_status },
 	{ "Shuffle",        prop_get_shuffle,         prop_set_shuffle },
@@ -1045,6 +1071,7 @@ static GvDbusProperty player_properties[] = {
 	{ "CanSeek",        prop_get_false,           NULL },
 	{ "CanControl",     prop_get_true,            NULL },
 	{ NULL,             NULL,                     NULL }
+	// clang-format on
 };
 
 static GVariant *
@@ -1070,9 +1097,11 @@ prop_get_tracks(GvDbusServer *dbus_server G_GNUC_UNUSED)
 }
 
 static GvDbusProperty tracklist_properties[] = {
+	// clang-format off
 	{ "Tracks",        prop_get_tracks, NULL },
 	{ "CanEditTracks", prop_get_true,   NULL },
 	{ NULL,            NULL,            NULL }
+	// clang-format on
 };
 
 static GVariant *
@@ -1104,10 +1133,12 @@ prop_get_active_playlist(GvDbusServer *dbus_server G_GNUC_UNUSED)
 }
 
 static GvDbusProperty playlists_properties[] = {
+	// clang-format off
 	{ "PlaylistCount",  prop_get_playlist_count,  NULL },
 	{ "Orderings",      prop_get_orderings,       NULL },
 	{ "ActivePlaylist", prop_get_active_playlist, NULL },
 	{ NULL,             NULL,                     NULL }
+	// clang-format on
 };
 
 /*
@@ -1115,11 +1146,13 @@ static GvDbusProperty playlists_properties[] = {
  */
 
 static GvDbusInterface dbus_interfaces[] = {
+	// clang-format off
 	{ DBUS_IFACE_ROOT,      root_methods,      root_properties      },
 	{ DBUS_IFACE_PLAYER,    player_methods,    player_properties    },
 	{ DBUS_IFACE_TRACKLIST, tracklist_methods, tracklist_properties },
 	{ DBUS_IFACE_PLAYLISTS, playlists_methods, playlists_properties },
 	{ NULL,                 NULL,              NULL                 }
+	// clang-format on
 };
 
 /*
@@ -1127,72 +1160,72 @@ static GvDbusInterface dbus_interfaces[] = {
  */
 
 static void
-on_player_notify(GvPlayer           *player,
-                 GParamSpec          *pspec,
-                 GvDbusServerMpris2 *self)
+on_player_notify(GvPlayer *player,
+		 GParamSpec *pspec,
+		 GvDbusServerMpris2 *self)
 {
 	GvDbusServer *dbus_server = GV_DBUS_SERVER(self);
 	const gchar *property_name = g_param_spec_get_name(pspec);
 
-	if (!g_strcmp0(property_name, "state")) {
-		gv_dbus_server_emit_signal_property_changed
-		(dbus_server, DBUS_IFACE_PLAYER, "PlaybackStatus",
-		 g_variant_new_playback_status(player));
+	if (!g_strcmp0(property_name, "playback-state")) {
+		gv_dbus_server_emit_signal_property_changed(
+			dbus_server, DBUS_IFACE_PLAYER, "PlaybackStatus",
+			g_variant_new_playback_status(player));
 
 	} else if (!g_strcmp0(property_name, "repeat")) {
-		gv_dbus_server_emit_signal_property_changed
-		(dbus_server, DBUS_IFACE_PLAYER, "LoopStatus",
-		 g_variant_new_loop_status(player));
+		gv_dbus_server_emit_signal_property_changed(
+			dbus_server, DBUS_IFACE_PLAYER, "LoopStatus",
+			g_variant_new_loop_status(player));
 
 	} else if (!g_strcmp0(property_name, "shuffle")) {
-		gv_dbus_server_emit_signal_property_changed
-		(dbus_server, DBUS_IFACE_PLAYER, "Shuffle",
-		 g_variant_new_shuffle(player));
+		gv_dbus_server_emit_signal_property_changed(
+			dbus_server, DBUS_IFACE_PLAYER, "Shuffle",
+			g_variant_new_shuffle(player));
 
 	} else if (!g_strcmp0(property_name, "volume")) {
-		gv_dbus_server_emit_signal_property_changed
-		(dbus_server, DBUS_IFACE_PLAYER, "Volume",
-		 g_variant_new_volume(player));
+		gv_dbus_server_emit_signal_property_changed(
+			dbus_server, DBUS_IFACE_PLAYER, "Volume",
+			g_variant_new_volume(player));
 
 	} else if (!g_strcmp0(property_name, "station")) {
 		GvStation *station = gv_player_get_station(player);
 		GvMetadata *metadata = gv_player_get_metadata(player);
 
-		gv_dbus_server_emit_signal_property_changed
-		(dbus_server, DBUS_IFACE_PLAYER, "Metadata",
-		 g_variant_new_metadata_map(station, metadata));
+		gv_dbus_server_emit_signal_property_changed(
+			dbus_server, DBUS_IFACE_PLAYER, "Metadata",
+			g_variant_new_metadata_map(station, metadata));
 
 		/* This signal should be sent only if there was a change */
-		gv_dbus_server_emit_signal_property_changed
-		(dbus_server, DBUS_IFACE_PLAYER, "CanGoPrevious",
-		 g_variant_new_can_go_prev(player));
+		gv_dbus_server_emit_signal_property_changed(
+			dbus_server, DBUS_IFACE_PLAYER, "CanGoPrevious",
+			g_variant_new_can_go_prev(player));
 
 		/* This signal should be sent only if there was a change */
-		gv_dbus_server_emit_signal_property_changed
-		(dbus_server, DBUS_IFACE_PLAYER, "CanGoNext",
-		 g_variant_new_can_go_next(player));
+		gv_dbus_server_emit_signal_property_changed(
+			dbus_server, DBUS_IFACE_PLAYER, "CanGoNext",
+			g_variant_new_can_go_next(player));
 
 		/* This signal should be send only if the station's name
 		 * or the station's icon was changed.
 		 */
-		gv_dbus_server_emit_signal_property_changed
-		(dbus_server, DBUS_IFACE_PLAYLISTS, "PlaylistChanged",
-		 g_variant_new_playlist(station));
+		gv_dbus_server_emit_signal_property_changed(
+			dbus_server, DBUS_IFACE_PLAYLISTS, "PlaylistChanged",
+			g_variant_new_playlist(station));
 
 	} else if (!g_strcmp0(property_name, "metadata")) {
 		GvStation *station = gv_player_get_station(player);
 		GvMetadata *metadata = gv_player_get_metadata(player);
 
-		gv_dbus_server_emit_signal_property_changed
-		(dbus_server, DBUS_IFACE_PLAYER, "Metadata",
-		 g_variant_new_metadata_map(station, metadata));
+		gv_dbus_server_emit_signal_property_changed(
+			dbus_server, DBUS_IFACE_PLAYER, "Metadata",
+			g_variant_new_metadata_map(station, metadata));
 	}
 }
 
 static void
-on_station_list_station_added(GvStationList      *station_list,
-                              GvStation          *station,
-                              GvDbusServerMpris2 *self)
+on_station_list_station_added(GvStationList *station_list,
+			      GvStation *station,
+			      GvDbusServerMpris2 *self)
 {
 	GvDbusServer *dbus_server = GV_DBUS_SERVER(self);
 	GVariantBuilder b;
@@ -1207,15 +1240,15 @@ on_station_list_station_added(GvStationList      *station_list,
 	g_variant_builder_add(&b, "o", after_track_id);
 
 	gv_dbus_server_emit_signal(dbus_server, DBUS_IFACE_TRACKLIST, "TrackAdded",
-	                           g_variant_builder_end(&b));
+				   g_variant_builder_end(&b));
 
 	g_free(after_track_id);
 }
 
 static void
-on_station_list_station_removed(GvStationList      *station_list G_GNUC_UNUSED,
-                                GvStation          *station,
-                                GvDbusServerMpris2 *self)
+on_station_list_station_removed(GvStationList *station_list G_GNUC_UNUSED,
+				GvStation *station,
+				GvDbusServerMpris2 *self)
 {
 	GvDbusServer *dbus_server = GV_DBUS_SERVER(self);
 	GVariantBuilder b;
@@ -1227,15 +1260,15 @@ on_station_list_station_removed(GvStationList      *station_list G_GNUC_UNUSED,
 	g_variant_builder_add(&b, "o", track_id);
 
 	gv_dbus_server_emit_signal(dbus_server, DBUS_IFACE_TRACKLIST, "TrackRemoved",
-	                           g_variant_builder_end(&b));
+				   g_variant_builder_end(&b));
 
 	g_free(track_id);
 }
 
 static void
-on_station_list_station_modified(GvStationList      *station_list G_GNUC_UNUSED,
-                                 GvStation          *station,
-                                 GvDbusServerMpris2 *self)
+on_station_list_station_modified(GvStationList *station_list G_GNUC_UNUSED,
+				 GvStation *station,
+				 GvDbusServerMpris2 *self)
 {
 	GvDbusServer *dbus_server = GV_DBUS_SERVER(self);
 	GVariantBuilder b;
@@ -1248,7 +1281,7 @@ on_station_list_station_modified(GvStationList      *station_list G_GNUC_UNUSED,
 	g_variant_builder_add_value(&b, g_variant_new_metadata_map(station, NULL));
 
 	gv_dbus_server_emit_signal(dbus_server, DBUS_IFACE_TRACKLIST, "TrackMetadataChanged",
-	                           g_variant_builder_end(&b));
+				   g_variant_builder_end(&b));
 
 	g_free(track_id);
 }
@@ -1281,13 +1314,14 @@ gv_dbus_server_mpris2_enable(GvFeature *feature)
 	GV_FEATURE_CHAINUP_ENABLE(gv_dbus_server_mpris2, feature);
 
 	/* Signal handlers */
-	g_signal_connect_object(player, "notify", G_CALLBACK(on_player_notify), feature, 0);
+	g_signal_connect_object(player, "notify",
+				G_CALLBACK(on_player_notify), feature, 0);
 	g_signal_connect_object(station_list, "station-added",
-	                        G_CALLBACK(on_station_list_station_added), feature, 0);
+				G_CALLBACK(on_station_list_station_added), feature, 0);
 	g_signal_connect_object(station_list, "station-removed",
-	                        G_CALLBACK(on_station_list_station_removed), feature, 0);
+				G_CALLBACK(on_station_list_station_removed), feature, 0);
 	g_signal_connect_object(station_list, "station-modified",
-	                        G_CALLBACK(on_station_list_station_modified), feature, 0);
+				G_CALLBACK(on_station_list_station_modified), feature, 0);
 }
 
 /*
