@@ -1,14 +1,13 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2020 Arnaud Rebillout
+ * Copyright (C) 2015-2021 Arnaud Rebillout
  *
- * SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-only
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,19 +15,19 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <signal.h>
 
-#include <glib.h>
 #include <glib-object.h>
+#include <glib.h>
 
 #include "base/gv-base.h"
 #include "core/gv-core.h"
 
-#include "feat/gv-inhibitor.h"
 #include "feat/gv-inhibitor-impl.h"
+#include "feat/gv-inhibitor.h"
 
 /*
  * GObject definitions
@@ -38,22 +37,22 @@ const gchar *gv_inhibitor_implementations[] = { "gtk", "pm", NULL };
 
 struct _GvInhibitorPrivate {
 	GvInhibitorImpl *impl;
-	gboolean         no_impl_available;
-	guint            check_playback_status_timeout_id;
+	gboolean no_impl_available;
+	guint check_playback_state_timeout_id;
 };
 
 typedef struct _GvInhibitorPrivate GvInhibitorPrivate;
 
 struct _GvInhibitor {
 	/* Parent instance structure */
-	GvFeature           parent_instance;
+	GvFeature parent_instance;
 	/* Private data */
 	GvInhibitorPrivate *priv;
 };
 
 G_DEFINE_TYPE_WITH_CODE(GvInhibitor, gv_inhibitor, GV_TYPE_FEATURE,
-                        G_ADD_PRIVATE(GvInhibitor)
-                        G_IMPLEMENT_INTERFACE(GV_TYPE_ERRORABLE, NULL))
+			G_ADD_PRIVATE(GvInhibitor)
+			G_IMPLEMENT_INTERFACE(GV_TYPE_ERRORABLE, NULL))
 
 static void
 gv_inhibitor_inhibit(GvInhibitor *self, const gchar *reason)
@@ -77,11 +76,11 @@ gv_inhibitor_inhibit(GvInhibitor *self, const gchar *reason)
 
 		if (ret == TRUE) {
 			DEBUG("Inhibited system sleep (%s)",
-				gv_inhibitor_impl_get_name(priv->impl));
+			      gv_inhibitor_impl_get_name(priv->impl));
 		} else {
 			DEBUG("Failed to inhibit system sleep (%s): %s",
-				gv_inhibitor_impl_get_name(priv->impl),
-				err ? err->message : "unknown error");
+			      gv_inhibitor_impl_get_name(priv->impl),
+			      err ? err->message : "unknown error");
 			g_clear_error(&err);
 		}
 
@@ -104,12 +103,12 @@ gv_inhibitor_inhibit(GvInhibitor *self, const gchar *reason)
 
 		if (ret == TRUE) {
 			DEBUG("Inhibited system sleep (%s)",
-				gv_inhibitor_impl_get_name(priv->impl));
+			      gv_inhibitor_impl_get_name(priv->impl));
 			break;
 		} else {
 			DEBUG("Failed to inhibit system sleep (%s): %s",
-				gv_inhibitor_impl_get_name(priv->impl),
-				err ? err->message : "unknown error");
+			      gv_inhibitor_impl_get_name(priv->impl),
+			      err ? err->message : "unknown error");
 			g_clear_object(&priv->impl);
 			g_clear_error(&err);
 		}
@@ -118,7 +117,7 @@ gv_inhibitor_inhibit(GvInhibitor *self, const gchar *reason)
 	if (impl == NULL) {
 		priv->no_impl_available = TRUE;
 		gv_errorable_emit_error(GV_ERRORABLE(self),
-				_("Failed to inhibit system sleep"));
+					_("Failed to inhibit system sleep"));
 	}
 }
 
@@ -134,35 +133,36 @@ gv_inhibitor_uninhibit(GvInhibitor *self)
 }
 
 static void
-gv_inhibitor_check_playback_status_now(GvInhibitor *self)
+gv_inhibitor_check_playback_state_now(GvInhibitor *self)
 {
-	GvPlayerState player_state = gv_player_get_state(gv_core_player);
+	GvPlaybackState playback_state;
 
-	if (player_state == GV_PLAYER_STATE_PLAYING)
+	playback_state = gv_player_get_playback_state(gv_core_player);
+	if (playback_state == GV_PLAYBACK_STATE_PLAYING)
 		gv_inhibitor_inhibit(self, _("Playing"));
 	else
 		gv_inhibitor_uninhibit(self);
 }
 
 static gboolean
-when_timeout_check_playback_status(GvInhibitor *self)
+when_timeout_check_playback_state(GvInhibitor *self)
 {
 	GvInhibitorPrivate *priv = self->priv;
 
-	gv_inhibitor_check_playback_status_now(self);
-	priv->check_playback_status_timeout_id = 0;
+	gv_inhibitor_check_playback_state_now(self);
+	priv->check_playback_state_timeout_id = 0;
 
 	return G_SOURCE_REMOVE;
 }
 
 static void
-gv_inhibitor_check_playback_status_delayed(GvInhibitor *self, guint delay)
+gv_inhibitor_check_playback_state_delayed(GvInhibitor *self, guint delay)
 {
 	GvInhibitorPrivate *priv = self->priv;
 
-	g_clear_handle_id(&priv->check_playback_status_timeout_id, g_source_remove);
-	priv->check_playback_status_timeout_id =
-	        g_timeout_add_seconds(delay, (GSourceFunc) when_timeout_check_playback_status, self);
+	g_clear_handle_id(&priv->check_playback_state_timeout_id, g_source_remove);
+	priv->check_playback_state_timeout_id =
+		g_timeout_add_seconds(delay, (GSourceFunc) when_timeout_check_playback_state, self);
 }
 
 /*
@@ -170,21 +170,23 @@ gv_inhibitor_check_playback_status_delayed(GvInhibitor *self, guint delay)
  */
 
 static void
-on_player_notify_state(GvPlayer    *player,
-                       GParamSpec  *pspec G_GNUC_UNUSED,
-                       GvInhibitor *self)
+on_player_notify_state(GvPlayer *player,
+		       GParamSpec *pspec G_GNUC_UNUSED,
+		       GvInhibitor *self)
 {
-	GvPlayerState player_state = gv_player_get_state(player);
+	GvPlaybackState playback_state;
+
+	playback_state = gv_player_get_playback_state(player);
 
 	/* 'connecting' and 'buffering' are intermediary states, so let's wait
 	 * a bit handling it, but let's schedule a callback all the same, just
 	 * in case the player gets stuck in one of those states for some reason.
 	 */
-	if (player_state == GV_PLAYER_STATE_CONNECTING ||
-	    player_state == GV_PLAYER_STATE_BUFFERING)
-		gv_inhibitor_check_playback_status_delayed(self, 10);
+	if (playback_state == GV_PLAYBACK_STATE_CONNECTING ||
+	    playback_state == GV_PLAYBACK_STATE_BUFFERING)
+		gv_inhibitor_check_playback_state_delayed(self, 10);
 	else
-		gv_inhibitor_check_playback_status_delayed(self, 1);
+		gv_inhibitor_check_playback_state_delayed(self, 1);
 }
 
 /*
@@ -201,7 +203,7 @@ gv_inhibitor_disable(GvFeature *feature)
 	TRACE("%p", feature);
 
 	/* Remove pending operation */
-	g_clear_handle_id(&priv->check_playback_status_timeout_id, g_source_remove);
+	g_clear_handle_id(&priv->check_playback_state_timeout_id, g_source_remove);
 
 	/* Cleanup */
 	g_clear_object(&priv->impl);
@@ -227,13 +229,14 @@ gv_inhibitor_enable(GvFeature *feature)
 	GV_FEATURE_CHAINUP_ENABLE(gv_inhibitor, feature);
 
 	/* Connect to signal handlers */
-	g_signal_connect_object(player, "notify::state", G_CALLBACK(on_player_notify_state),
-	                        self, 0);
+	g_signal_connect_object(player, "notify::playback-state",
+				G_CALLBACK(on_player_notify_state),
+				self, 0);
 
 	/* Schedule a check for the current playback status */
-	g_assert(priv->check_playback_status_timeout_id == 0);
-	priv->check_playback_status_timeout_id =
-	        g_timeout_add_seconds(1, (GSourceFunc) when_timeout_check_playback_status, self);
+	g_assert(priv->check_playback_state_timeout_id == 0);
+	priv->check_playback_state_timeout_id =
+		g_timeout_add_seconds(1, (GSourceFunc) when_timeout_check_playback_state, self);
 }
 
 /*
