@@ -1,14 +1,13 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2020 Arnaud Rebillout
+ * Copyright (C) 2015-2021 Arnaud Rebillout
  *
- * SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-only
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,12 +15,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
-#include <glib.h>
-#include <glib-object.h>
 #include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
 
 #include "base/glib-additions.h"
 #include "base/gv-base.h"
@@ -29,7 +28,7 @@
 
 #include "feat/gv-notifications.h"
 
-#define NOTIF_ID_ERROR   "error"
+#define NOTIF_ID_ERROR	 "error"
 #define NOTIF_ID_PLAYING "playing"
 
 /*
@@ -133,26 +132,26 @@ make_error_notification(const gchar *error_string)
  */
 
 static void
-on_player_notify(GvPlayer        *player,
-                 GParamSpec      *pspec,
-                 GvNotifications *self G_GNUC_UNUSED)
+on_player_notify(GvPlayer *player,
+		 GParamSpec *pspec,
+		 GvNotifications *self G_GNUC_UNUSED)
 {
 	const gchar *property_name = g_param_spec_get_name(pspec);
 	GApplication *app = gv_core_application;
 
-	if (!g_strcmp0(property_name, "state")) {
+	if (!g_strcmp0(property_name, "playback-state")) {
 		GNotification *notif;
-		GvPlayerState state;
+		GvPlaybackState state;
 		GvStation *station;
 
-		state = gv_player_get_state(player);
+		state = gv_player_get_playback_state(player);
 
-		if (state == GV_PLAYER_STATE_STOPPED) {
+		if (state == GV_PLAYBACK_STATE_STOPPED) {
 			g_application_withdraw_notification(app, NOTIF_ID_PLAYING);
 			return;
 		}
 
-		if (state != GV_PLAYER_STATE_PLAYING)
+		if (state != GV_PLAYBACK_STATE_PLAYING)
 			return;
 
 		station = gv_player_get_station(player);
@@ -178,9 +177,9 @@ on_player_notify(GvPlayer        *player,
 }
 
 static void
-on_errorable_error(GvErrorable     *errorable,
-                   const gchar     *error_string,
-                   GvNotifications *self)
+on_errorable_error(GvErrorable *errorable,
+		   const gchar *error_string,
+		   GvNotifications *self)
 {
 	GApplication *app = gv_core_application;
 	GNotification *notif;
@@ -274,6 +273,6 @@ gv_notifications_class_init(GvNotificationsClass *class)
 	TRACE("%p", class);
 
 	/* Override GvFeature methods */
-	feature_class->enable  = gv_notifications_enable;
+	feature_class->enable = gv_notifications_enable;
 	feature_class->disable = gv_notifications_disable;
 }
