@@ -1,14 +1,13 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2020 Arnaud Rebillout
+ * Copyright (C) 2015-2021 Arnaud Rebillout
  *
- * SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-only
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,13 +15,13 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
-#include <string.h>
-#include <glib.h>
 #include <glib-object.h>
+#include <glib.h>
 #include <gtk/gtk.h>
+#include <string.h>
 
 #include "base/glib-object-additions.h"
 #include "base/gv-base.h"
@@ -34,6 +33,8 @@
 
 #define UI_RESOURCE_PATH GV_APPLICATION_PATH "/Ui/station-dialog.glade"
 
+#define DEFAULT_WINDOW_WIDTH 480
+
 /*
  * Properties
  */
@@ -55,11 +56,12 @@ static GParamSpec *properties[PROP_N];
 
 struct _GvStationDialogPrivate {
 	/* Widgets */
-	/* Top-level */
 	GtkWidget *main_grid;
-	/* Entries */
 	GtkWidget *name_entry;
 	GtkWidget *uri_entry;
+	GtkWidget *sec_hbox;
+	GtkWidget *sec_label;
+	GtkWidget *sec_button;
 	/* Buttons */
 	GtkWidget *save_button;
 	/* Existing station if any */
@@ -70,7 +72,7 @@ typedef struct _GvStationDialogPrivate GvStationDialogPrivate;
 
 struct _GvStationDialog {
 	/* Parent instance structure */
-	GtkDialog               parent_instance;
+	GtkDialog parent_instance;
 	/* Private data */
 	GvStationDialogPrivate *priv;
 };
@@ -113,10 +115,10 @@ remove_weird_chars(const gchar *text, gchar **out, guint *out_len)
 
 static void
 on_uri_entry_insert_text(GtkEditable *editable,
-                         gchar       *text,
-                         gint         length G_GNUC_UNUSED,
-                         gpointer     position,
-                         GvStationDialog *self)
+			 gchar *text,
+			 gint length G_GNUC_UNUSED,
+			 gpointer position,
+			 GvStationDialog *self)
 {
 	gchar *new_text;
 	guint new_len;
@@ -126,14 +128,14 @@ on_uri_entry_insert_text(GtkEditable *editable,
 
 	/* Replace text in entry */
 	g_signal_handlers_block_by_func(editable,
-	                                on_uri_entry_insert_text,
-	                                self);
+					on_uri_entry_insert_text,
+					self);
 
 	gtk_editable_insert_text(editable, new_text, new_len, position);
 
 	g_signal_handlers_unblock_by_func(editable,
-	                                  on_uri_entry_insert_text,
-	                                  self);
+					  on_uri_entry_insert_text,
+					  self);
 
 	/* We inserted the text in the entry, so now we just need to
 	 * prevent the default handler to run.
@@ -146,7 +148,7 @@ on_uri_entry_insert_text(GtkEditable *editable,
 
 static void
 on_uri_entry_changed(GtkEditable *editable,
-                     GvStationDialog *self)
+		     GvStationDialog *self)
 {
 	GvStationDialogPrivate *priv = self->priv;
 	guint text_len;
@@ -160,6 +162,19 @@ on_uri_entry_changed(GtkEditable *editable,
 		gtk_widget_set_sensitive(priv->save_button, FALSE);
 }
 
+static void
+on_sec_button_clicked(GtkButton *button G_GNUC_UNUSED,
+		      GvStationDialog *self)
+{
+	GvStationDialogPrivate *priv = self->priv;
+	GtkWidget *sec_hbox = priv->sec_hbox;
+	GtkWidget *sec_label = priv->sec_label;
+
+	/* We don't do it yet */
+	gtk_label_set_text(GTK_LABEL(sec_label), _("Security Exception removed"));
+	gtk_widget_set_sensitive(sec_hbox, FALSE);
+}
+
 /*
  * Property accessors
  */
@@ -175,10 +190,10 @@ gv_station_dialog_set_station(GvStationDialog *self, GvStation *station)
 }
 
 static void
-gv_station_dialog_get_property(GObject    *object,
-                               guint       property_id,
-                               GValue     *value,
-                               GParamSpec *pspec)
+gv_station_dialog_get_property(GObject *object,
+			       guint property_id,
+			       GValue *value,
+			       GParamSpec *pspec)
 {
 	TRACE_GET_PROPERTY(object, property_id, value, pspec);
 
@@ -186,10 +201,10 @@ gv_station_dialog_get_property(GObject    *object,
 }
 
 static void
-gv_station_dialog_set_property(GObject      *object,
-                               guint         property_id,
-                               const GValue *value,
-                               GParamSpec   *pspec)
+gv_station_dialog_set_property(GObject *object,
+			       guint property_id,
+			       const GValue *value,
+			       GParamSpec *pspec)
 {
 	GvStationDialog *self = GV_STATION_DIALOG(object);
 
@@ -215,9 +230,13 @@ gv_station_dialog_retrieve(GvStationDialog *self, GvStation *station)
 	GvStationDialogPrivate *priv = self->priv;
 	GtkEntry *name_entry = GTK_ENTRY(priv->name_entry);
 	GtkEntry *uri_entry = GTK_ENTRY(priv->uri_entry);
+	GtkWidget *sec_hbox = priv->sec_hbox;
 
 	gv_station_set_name(station, gtk_entry_get_text(name_entry));
 	gv_station_set_uri(station, gtk_entry_get_text(uri_entry));
+	if (gtk_widget_get_visible(sec_hbox) == TRUE &&
+	    gtk_widget_get_sensitive(sec_hbox) == FALSE)
+		gv_station_set_insecure(station, FALSE);
 }
 
 GvStation *
@@ -264,13 +283,12 @@ gv_station_dialog_populate_widgets(GvStationDialog *self)
 	builder = gtk_builder_new_from_resource(UI_RESOURCE_PATH);
 
 	/* Save widget pointers */
-
-	/* Top-level */
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, main_grid);
-
-	/* Text entries */
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, name_entry);
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, uri_entry);
+	GTK_BUILDER_SAVE_WIDGET(builder, priv, sec_hbox);
+	GTK_BUILDER_SAVE_WIDGET(builder, priv, sec_label);
+	GTK_BUILDER_SAVE_WIDGET(builder, priv, sec_button);
 
 	/* Add to content area */
 	content_area = gtk_dialog_get_content_area(GTK_DIALOG(self));
@@ -278,11 +296,11 @@ gv_station_dialog_populate_widgets(GvStationDialog *self)
 
 	/* Populate the action area */
 	gtk_dialog_add_buttons(GTK_DIALOG(self),
-	                       _("Cancel"), GTK_RESPONSE_CANCEL,
-	                       _("Save"), GTK_RESPONSE_OK,
-	                       NULL);
-	priv->save_button = gtk_dialog_get_widget_for_response
-	                    (GTK_DIALOG(self), GTK_RESPONSE_OK);
+			       _("Cancel"), GTK_RESPONSE_CANCEL,
+			       _("Save"), GTK_RESPONSE_OK,
+			       NULL);
+	priv->save_button = gtk_dialog_get_widget_for_response(
+		GTK_DIALOG(self), GTK_RESPONSE_OK);
 
 	/* Cleanup */
 	g_object_unref(builder);
@@ -294,10 +312,12 @@ gv_station_dialog_setup_widgets(GvStationDialog *self)
 	GvStationDialogPrivate *priv = self->priv;
 	GtkEntry *name_entry = GTK_ENTRY(priv->name_entry);
 	GtkEntry *uri_entry = GTK_ENTRY(priv->uri_entry);
+	GtkWidget *sec_hbox = priv->sec_hbox;
+	GtkButton *sec_button = GTK_BUTTON(priv->sec_button);
 	GvStation *station = priv->station;
 
-	/* We don't allow creating a station without an empty uri, therefore
-	 * the save button is insensitive when the uri empty. We can set it
+	/* We don't allow creating a station with an empty uri, therefore
+	 * the save button is insensitive when the uri is empty. We can set it
 	 * insensitive now because of the following code...
 	 * Watch out if you change something here!
 	 */
@@ -306,9 +326,9 @@ gv_station_dialog_setup_widgets(GvStationDialog *self)
 	/* Configure uri widget */
 	gtk_entry_set_input_purpose(uri_entry, GTK_INPUT_PURPOSE_URL);
 	g_signal_connect_object(uri_entry, "insert-text", G_CALLBACK(on_uri_entry_insert_text),
-	                        self, 0);
+				self, 0);
 	g_signal_connect_object(uri_entry, "changed", G_CALLBACK(on_uri_entry_changed),
-	                        self, 0);
+				self, 0);
 
 	/* Fill widgets with station info */
 	if (station) {
@@ -322,22 +342,35 @@ gv_station_dialog_setup_widgets(GvStationDialog *self)
 		if (uri)
 			gtk_entry_set_text(uri_entry, uri);
 	}
+
+	/* Security exception is shown only if insecure is true */
+	if (station && gv_station_get_insecure(station) == TRUE) {
+		gtk_widget_set_visible(sec_hbox, TRUE);
+		g_signal_connect_object(sec_button, "clicked",
+					G_CALLBACK(on_sec_button_clicked), self, 0);
+	} else {
+		gtk_widget_set_visible(sec_hbox, FALSE);
+	}
 }
 
 static void
 gv_station_dialog_setup_appearance(GvStationDialog *self)
 {
 	GvStationDialogPrivate *priv = self->priv;
+	GtkWidget *content_area;
 
-	/* Main window */
-	gtk_window_set_default_size(GTK_WINDOW(self), 400, -1);
+	gtk_window_set_default_size(GTK_WINDOW(self), DEFAULT_WINDOW_WIDTH, -1);
+
+	content_area = gtk_dialog_get_content_area(GTK_DIALOG(self));
+	g_object_set(content_area,
+		     "margin", GV_UI_WINDOW_MARGIN,
+		     "spacing", GV_UI_WINDOW_MARGIN,
+		     NULL);
 
-	/* Main grid */
 	g_object_set(priv->main_grid,
-	             "margin", GV_UI_WINDOW_BORDER,
-	             "row-spacing", GV_UI_ELEM_SPACING,
-	             "column-spacing", GV_UI_COLUMN_SPACING,
-	             NULL);
+		     "row-spacing", GV_UI_ELEM_SPACING,
+		     "column-spacing", GV_UI_COLUMN_SPACING,
+		     NULL);
 }
 
 /*
@@ -399,8 +432,8 @@ gv_station_dialog_class_init(GvStationDialogClass *class)
 	object_class->set_property = gv_station_dialog_set_property;
 
 	properties[PROP_STATION] =
-	        g_param_spec_object("station", "Station", NULL, GV_TYPE_STATION,
-	                            GV_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
+		g_param_spec_object("station", "Station", NULL, GV_TYPE_STATION,
+				    GV_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
 
 	g_object_class_install_properties(object_class, PROP_N, properties);
 }
@@ -419,8 +452,7 @@ make_station_dialog(GtkWindow *parent, GvStation *station)
 	gtk_window_set_skip_taskbar_hint(GTK_WINDOW(dialog), TRUE);
 	gtk_window_set_transient_for(GTK_WINDOW(dialog), parent);
 	gtk_window_set_destroy_with_parent(GTK_WINDOW(dialog), TRUE);
-	gtk_window_set_title(GTK_WINDOW(dialog), station ?
-	                     _("Edit Station") : _("Add Station"));
+	gtk_window_set_title(GTK_WINDOW(dialog), station ? _("Edit Station") : _("Add Station"));
 
 	/* When 'Add Station' is invoked from the popup menu, in status icon mode,
 	 * we want a better position than centering on screen.
@@ -465,15 +497,15 @@ gv_show_add_station_dialog(GtkWindow *parent)
 	 * that the user intends to add this station to the list, so we save him a bit
 	 * of time and populate the dialog with this uri.
 	 */
-	GvPlayer      *player       = gv_core_player;
+	GvPlayer *player = gv_core_player;
 	GvStationList *station_list = gv_core_station_list;
-	GvStation     *current_station;
+	GvStation *current_station;
 
 	current_station = gv_player_get_station(player);
 	if (current_station &&
 	    gv_station_list_find(station_list, current_station) == NULL) {
 		gv_station_dialog_fill_uri(GV_STATION_DIALOG(dialog),
-		                           gv_station_get_uri(current_station));
+					   gv_station_get_uri(current_station));
 	}
 
 	/* Run */
