@@ -1,14 +1,13 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2020 Arnaud Rebillout
+ * Copyright (C) 2015-2021 Arnaud Rebillout
  *
- * SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-only
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,11 +15,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
-#include <glib.h>
 #include <glib-object.h>
+#include <glib.h>
 #include <gtk/gtk.h>
 
 #include "base/glib-object-additions.h"
@@ -83,9 +82,9 @@ enum {
  */
 
 static void
-on_player_notify_station(GvPlayer           *player,
-                         GParamSpec         *pspec G_GNUC_UNUSED,
-                         GvStationsTreeView *self)
+on_player_notify_station(GvPlayer *player,
+			 GParamSpec *pspec G_GNUC_UNUSED,
+			 GvStationsTreeView *self)
 {
 	GtkTreeView *tree_view = GTK_TREE_VIEW(self);
 	GtkTreeModel *tree_model = gtk_tree_view_get_model(tree_view);
@@ -100,18 +99,18 @@ on_player_notify_station(GvPlayer           *player,
 
 		/* Get station from model */
 		gtk_tree_model_get(tree_model, &iter,
-		                   STATION_COLUMN, &iter_station,
-		                   -1);
+				   STATION_COLUMN, &iter_station,
+				   -1);
 
 		/* Make the current station bold */
 		if (station == iter_station)
 			gtk_list_store_set(GTK_LIST_STORE(tree_model), &iter,
-			                   STATION_WEIGHT_COLUMN, PANGO_WEIGHT_BOLD,
-			                   -1);
+					   STATION_WEIGHT_COLUMN, PANGO_WEIGHT_BOLD,
+					   -1);
 		else
 			gtk_list_store_set(GTK_LIST_STORE(tree_model), &iter,
-			                   STATION_WEIGHT_COLUMN, PANGO_WEIGHT_NORMAL,
-			                   -1);
+					   STATION_WEIGHT_COLUMN, PANGO_WEIGHT_NORMAL,
+					   -1);
 
 		/* Unref the station */
 		if (iter_station)
@@ -130,7 +129,7 @@ on_player_notify_station(GvPlayer           *player,
 
 static void
 on_station_list_loaded(GvStationList *station_list,
-                       GvStationsTreeView  *self)
+		       GvStationsTreeView *self)
 {
 	TRACE("%p, %p", station_list, self);
 
@@ -139,8 +138,8 @@ on_station_list_loaded(GvStationList *station_list,
 
 static void
 on_station_list_station_event(GvStationList *station_list,
-                              GvStation     *station,
-                              GvStationsTreeView *self)
+			      GvStation *station,
+			      GvStationsTreeView *self)
 {
 	TRACE("%p, %p, %p", station_list, station, self);
 
@@ -148,77 +147,47 @@ on_station_list_station_event(GvStationList *station_list,
 }
 
 static GSignalHandler station_list_handlers[] = {
+	// clang-format off
 	{ "loaded",           G_CALLBACK(on_station_list_loaded)        },
 	{ "station-added",    G_CALLBACK(on_station_list_station_event) },
 	{ "station-removed",  G_CALLBACK(on_station_list_station_event) },
 	{ "station-modified", G_CALLBACK(on_station_list_station_event) },
 	{ "station-moved",    G_CALLBACK(on_station_list_station_event) },
 	{ NULL,               NULL                                      }
+	// clang-format on
 };
 
-#if 0
 /*
  * Stations tree view row activated
  * Might be caused by mouse action (single click on the row),
- * or by keyboard action (Enter or similar key pressed).
+ * or a gesture (touch on a touchscreen), or a keyboard action
+ * (Enter or similar key pressed).
  */
 
 static void
 on_tree_view_row_activated(GvStationsTreeView *self,
-                           GtkTreePath         *path,
-                           GtkTreeViewColumn   *column G_GNUC_UNUSED,
-                           gpointer             data G_GNUC_UNUSED)
+			   GtkTreePath         *path,
+			   GtkTreeViewColumn   *column G_GNUC_UNUSED,
+			   gpointer             data G_GNUC_UNUSED)
 {
-	GvStationsTreeViewPrivate *priv = self->priv;
 	GtkTreeView *tree_view = GTK_TREE_VIEW(self);
 	GtkTreeModel *tree_model = gtk_tree_view_get_model(tree_view);
-	GtkTreeIter iter;
-	GvStation *station;
-
-	/* Get station from model */
-	gtk_tree_model_get_iter(tree_model, &iter, path);
-	gtk_tree_model_get(tree_model, &iter,
-	                   STATION_COLUMN, &station,
-	                   -1);
-
-	/* Play station */
-	if (station) {
-		GvPlayer *player = gv_core_player;
-
-		gv_player_set_station(player, station);
-		gv_player_play(player);
-		g_object_unref(station);
-	}
-
-	DEBUG("Row activated");
-}
-#else
-static gboolean
-when_idle_tree_view_row_activated(GvStationsTreeView *self)
-{
-	GvStationsTreeViewPrivate *priv = self->priv;
-	GtkTreeView *tree_view = GTK_TREE_VIEW(self);
-	GtkTreeSelection *tree_selection = gtk_tree_view_get_selection(tree_view);
-	GtkTreeModel *tree_model = gtk_tree_view_get_model(tree_view);
 	GvPlayer *player = gv_core_player;
+	GvStation *station = NULL;
 	GtkTreeIter iter;
-	GvStation *station;
+	gboolean ret;
 
-	/* Check if a drag operation is in progress */
-	if (priv->is_dragging) {
-		DEBUG("Drag'n'drop operation in progress");
-		return FALSE;
-	}
+	DEBUG("Row activated");
+
+	/* Get iterator */
+	ret = gtk_tree_model_get_iter(tree_model, &iter, path);
+	if (ret == FALSE)
+		return;
 
 	/* Get station */
-	gtk_tree_selection_get_selected(tree_selection, &tree_model, &iter);
-	gtk_tree_model_get(tree_model, &iter,
-	                   STATION_COLUMN, &station,
-	                   -1);
-
-	/* Station might be NULL if the station list is empty */
+	gtk_tree_model_get(tree_model, &iter, STATION_COLUMN, &station, -1);
 	if (station == NULL)
-		return FALSE;
+		return;
 
 	/* Play station */
 	gv_player_set_station(player, station);
@@ -226,38 +195,8 @@ when_idle_tree_view_row_activated(GvStationsTreeView *self)
 
 	/* Cleanup */
 	g_object_unref(station);
-
-	return FALSE;
 }
 
-/*
- * Stations Tree View row-activated
- * Might be caused by mouse action (single click on the row),
- * or by keyboard action (Enter or similar key pressed).
- */
-
-static void
-on_tree_view_row_activated(GvStationsTreeView *self,
-                           GtkTreePath         *path G_GNUC_UNUSED,
-                           GtkTreeViewColumn   *column G_GNUC_UNUSED,
-                           gpointer             data G_GNUC_UNUSED)
-{
-	DEBUG("Row activated, delaying...");
-
-	/* This signal might be received when the user clicks an item,
-	 * when he hits 'Enter' or similar on the keyboards,
-	 * but also when a drag'n'drop operation is performed, BEFORE
-	 * the 'drag-begin' signal is send.
-	 * In such case, we want to do nothing, but we don't know yet
-	 * that a drag'n'drop was started...
-	 * So, we have to delay the execution of the code a little bit.
-	 * We must give time to the 'drag-begin' signal to be emitted.
-	 */
-
-	g_idle_add((GSourceFunc) when_idle_tree_view_row_activated, self);
-}
-#endif
-
 /*
  * Stations Tree View button-press-event, for context menu on right-click
  */
@@ -278,8 +217,8 @@ on_context_menu_hide(GtkWidget *widget, GvStationsTreeView *self)
 
 static gboolean
 on_tree_view_button_press_event(GvStationsTreeView *self,
-                                GdkEventButton     *event,
-                                gpointer            data G_GNUC_UNUSED)
+				GdkEventButton *event,
+				gpointer data G_GNUC_UNUSED)
 
 {
 	GvStationsTreeViewPrivate *priv = self->priv;
@@ -314,7 +253,7 @@ on_tree_view_button_press_event(GvStationsTreeView *self,
 	/* Get row at this position */
 	path = NULL;
 	gtk_tree_view_get_path_at_pos(tree_view, event->x, event->y,
-	                              &path, NULL, NULL, NULL);
+				      &path, NULL, NULL, NULL);
 
 	/* Get corresponding station */
 	station = NULL;
@@ -322,8 +261,8 @@ on_tree_view_button_press_event(GvStationsTreeView *self,
 		GtkTreeIter iter;
 		gtk_tree_model_get_iter(tree_model, &iter, path);
 		gtk_tree_model_get(tree_model, &iter,
-		                   STATION_COLUMN, &station,
-		                   -1);
+				   STATION_COLUMN, &station,
+				   -1);
 	}
 
 	/* Create the context menu */
@@ -335,16 +274,16 @@ on_tree_view_button_press_event(GvStationsTreeView *self,
 	}
 
 	/* Pop it up */
-#if GTK_CHECK_VERSION(3,22,0)
+#if GTK_CHECK_VERSION(3, 22, 0)
 	gtk_menu_popup_at_pointer(GTK_MENU(context_menu), NULL);
 #else
 	gtk_menu_popup(GTK_MENU(context_menu),
-	               NULL,
-	               NULL,
-	               NULL,
-	               NULL,
-	               event->button,
-	               event->time);
+		       NULL,
+		       NULL,
+		       NULL,
+		       NULL,
+		       event->button,
+		       event->time);
 #endif
 
 	/* Save it for later use, handle destruction in callback */
@@ -364,8 +303,8 @@ on_tree_view_button_press_event(GvStationsTreeView *self,
 
 static void
 on_tree_view_drag_begin(GvStationsTreeView *self,
-                        GdkDragContext      *context G_GNUC_UNUSED,
-                        gpointer             data G_GNUC_UNUSED)
+			GdkDragContext *context G_GNUC_UNUSED,
+			gpointer data G_GNUC_UNUSED)
 {
 	GvStationsTreeViewPrivate *priv = self->priv;
 
@@ -374,20 +313,19 @@ on_tree_view_drag_begin(GvStationsTreeView *self,
 
 static void
 on_tree_view_drag_end(GvStationsTreeView *self,
-                      GdkDragContext      *context G_GNUC_UNUSED,
-                      gpointer             data G_GNUC_UNUSED)
+		      GdkDragContext *context G_GNUC_UNUSED,
+		      gpointer data G_GNUC_UNUSED)
 {
 	GvStationsTreeViewPrivate *priv = self->priv;
 
 	priv->is_dragging = FALSE;
 }
 
-
 static gboolean
 on_tree_view_drag_failed(GvStationsTreeView *self,
-                         GdkDragContext      *context G_GNUC_UNUSED,
-                         GtkDragResult        result,
-                         gpointer             data G_GNUC_UNUSED)
+			 GdkDragContext *context G_GNUC_UNUSED,
+			 GtkDragResult result,
+			 gpointer data G_GNUC_UNUSED)
 {
 	GvStationsTreeViewPrivate *priv = self->priv;
 
@@ -398,10 +336,12 @@ on_tree_view_drag_failed(GvStationsTreeView *self,
 }
 
 static GSignalHandler tree_view_drag_handlers[] = {
+	// clang-format off
 	{ "drag-begin",  G_CALLBACK(on_tree_view_drag_begin)  },
 	{ "drag-end",    G_CALLBACK(on_tree_view_drag_end)    },
 	{ "drag-failed", G_CALLBACK(on_tree_view_drag_failed) },
 	{ NULL,          NULL                                 }
+	// clang-format on
 };
 
 /*
@@ -419,10 +359,10 @@ static GSignalHandler tree_view_drag_handlers[] = {
  */
 
 static void
-on_list_store_row_inserted(GtkTreeModel        *tree_model G_GNUC_UNUSED,
-                           GtkTreePath         *path,
-                           GtkTreeIter         *iter G_GNUC_UNUSED,
-                           GvStationsTreeView *self)
+on_list_store_row_inserted(GtkTreeModel *tree_model G_GNUC_UNUSED,
+			   GtkTreePath *path,
+			   GtkTreeIter *iter G_GNUC_UNUSED,
+			   GvStationsTreeView *self)
 {
 	GvStationsTreeViewPrivate *priv = self->priv;
 	gint *indices;
@@ -449,10 +389,10 @@ on_list_store_row_inserted(GtkTreeModel        *tree_model G_GNUC_UNUSED,
 }
 
 static void
-on_list_store_row_changed(GtkTreeModel        *tree_model,
-                          GtkTreePath         *path,
-                          GtkTreeIter         *iter,
-                          GvStationsTreeView *self)
+on_list_store_row_changed(GtkTreeModel *tree_model,
+			  GtkTreePath *path,
+			  GtkTreeIter *iter,
+			  GvStationsTreeView *self)
 {
 	GvStationsTreeViewPrivate *priv = self->priv;
 	GvStation *station;
@@ -470,14 +410,14 @@ on_list_store_row_changed(GtkTreeModel        *tree_model,
 	position = indices[0];
 	if (position != priv->station_new_pos) {
 		WARNING("Unexpected position %d, doesn't match %d",
-		        position, priv->station_new_pos);
+			position, priv->station_new_pos);
 		return;
 	}
 
 	/* Get station */
 	gtk_tree_model_get(tree_model, iter,
-	                   STATION_COLUMN, &station,
-	                   -1);
+			   STATION_COLUMN, &station,
+			   -1);
 
 	/* Save it */
 	priv->station_dragged = station;
@@ -489,9 +429,9 @@ on_list_store_row_changed(GtkTreeModel        *tree_model,
 }
 
 static void
-on_list_store_row_deleted(GtkTreeModel        *tree_model G_GNUC_UNUSED,
-                          GtkTreePath         *path G_GNUC_UNUSED,
-                          GvStationsTreeView *self)
+on_list_store_row_deleted(GtkTreeModel *tree_model G_GNUC_UNUSED,
+			  GtkTreePath *path G_GNUC_UNUSED,
+			  GvStationsTreeView *self)
 {
 	GvStationsTreeViewPrivate *priv = self->priv;
 	GtkTreeView *tree_view = GTK_TREE_VIEW(self);
@@ -527,10 +467,12 @@ on_list_store_row_deleted(GtkTreeModel        *tree_model G_GNUC_UNUSED,
 }
 
 static GSignalHandler list_store_handlers[] = {
-	{ "row-inserted",          G_CALLBACK(on_list_store_row_inserted) },
-	{ "row-changed",           G_CALLBACK(on_list_store_row_changed)  },
-	{ "row-deleted",           G_CALLBACK(on_list_store_row_deleted)  },
-	{ NULL,                    NULL                        }
+	// clang-format off
+	{ "row-inserted", G_CALLBACK(on_list_store_row_inserted) },
+	{ "row-changed",  G_CALLBACK(on_list_store_row_changed)  },
+	{ "row-deleted",  G_CALLBACK(on_list_store_row_deleted)  },
+	{ NULL,           NULL                                   }
+	// clang-format on
 };
 
 /*
@@ -539,10 +481,10 @@ static GSignalHandler list_store_handlers[] = {
 
 static void
 station_cell_data_func(GtkTreeViewColumn *tree_column G_GNUC_UNUSED,
-                       GtkCellRenderer   *cell,
-                       GtkTreeModel      *tree_model,
-                       GtkTreeIter       *iter,
-                       gpointer           data G_GNUC_UNUSED)
+		       GtkCellRenderer *cell,
+		       GtkTreeModel *tree_model,
+		       GtkTreeIter *iter,
+		       gpointer data G_GNUC_UNUSED)
 {
 	gchar *station_name;
 	PangoWeight station_weight;
@@ -553,16 +495,16 @@ station_cell_data_func(GtkTreeViewColumn *tree_column G_GNUC_UNUSED,
 	 */
 
 	gtk_tree_model_get(tree_model, iter,
-	                   STATION_NAME_COLUMN, &station_name,
-	                   STATION_WEIGHT_COLUMN, &station_weight,
-	                   STATION_STYLE_COLUMN, &station_style,
-	                   -1);
+			   STATION_NAME_COLUMN, &station_name,
+			   STATION_WEIGHT_COLUMN, &station_weight,
+			   STATION_STYLE_COLUMN, &station_style,
+			   -1);
 
 	g_object_set(cell,
-	             "text", station_name,
-	             "weight", station_weight,
-	             "style", station_style,
-	             NULL);
+		     "text", station_name,
+		     "weight", station_weight,
+		     "style", station_style,
+		     NULL);
 
 	g_free(station_name);
 }
@@ -596,11 +538,11 @@ gv_stations_tree_view_populate(GvStationsTreeView *self)
 		/* Populate */
 		gtk_list_store_append(list_store, &tree_iter);
 		gtk_list_store_set(list_store, &tree_iter,
-		                   STATION_COLUMN, NULL,
-		                   STATION_NAME_COLUMN, "Right click to add station",
-		                   STATION_WEIGHT_COLUMN, PANGO_WEIGHT_NORMAL,
-		                   STATION_STYLE_COLUMN, PANGO_STYLE_ITALIC,
-		                   -1);
+				   STATION_COLUMN, NULL,
+				   STATION_NAME_COLUMN, "Right click to add station",
+				   STATION_WEIGHT_COLUMN, PANGO_WEIGHT_NORMAL,
+				   STATION_STYLE_COLUMN, PANGO_STYLE_ITALIC,
+				   -1);
 
 		/* Configure behavior */
 		gtk_tree_view_set_hover_selection(tree_view, FALSE);
@@ -628,11 +570,11 @@ gv_stations_tree_view_populate(GvStationsTreeView *self)
 
 			gtk_list_store_append(list_store, &tree_iter);
 			gtk_list_store_set(list_store, &tree_iter,
-			                   STATION_COLUMN, station,
-			                   STATION_NAME_COLUMN, station_name,
-			                   STATION_WEIGHT_COLUMN, weight,
-			                   STATION_STYLE_COLUMN, PANGO_STYLE_NORMAL,
-			                   -1);
+					   STATION_COLUMN, station,
+					   STATION_NAME_COLUMN, station_name,
+					   STATION_WEIGHT_COLUMN, weight,
+					   STATION_STYLE_COLUMN, PANGO_STYLE_NORMAL,
+					   -1);
 		}
 		gv_station_list_iter_free(iter);
 
@@ -725,13 +667,12 @@ gv_stations_tree_view_constructed(GObject *object)
 
 	/* Create a column that uses this renderer */
 	GtkTreeViewColumn *column;
-	column = gtk_tree_view_column_new_with_attributes
-	         ("Station", renderer, NULL);
+	column = gtk_tree_view_column_new_with_attributes("Station", renderer, NULL);
 
 	/* Set the function that will render this column */
 	gtk_tree_view_column_set_cell_data_func(column, renderer,
-	                                        station_cell_data_func,
-	                                        NULL, NULL);
+						station_cell_data_func,
+						NULL, NULL);
 
 	/* Append the column */
 	gtk_tree_view_append_column(tree_view, column);
@@ -742,11 +683,11 @@ gv_stations_tree_view_constructed(GObject *object)
 
 	/* Left click or keyboard */
 	g_signal_connect_object(tree_view, "row-activated",
-	                        G_CALLBACK(on_tree_view_row_activated), NULL, 0);
+				G_CALLBACK(on_tree_view_row_activated), NULL, 0);
 
 	/* We handle the right-click here */
 	g_signal_connect_object(tree_view, "button-press-event",
-	                        G_CALLBACK(on_tree_view_button_press_event), NULL, 0);
+				G_CALLBACK(on_tree_view_button_press_event), NULL, 0);
 
 	/* Drag-n-drop signal handlers.
 	 * We need to watch it just to know when a drag-n-drop is in progress.
@@ -768,7 +709,7 @@ gv_stations_tree_view_constructed(GObject *object)
 	GvStationList *station_list = gv_core_station_list;
 
 	g_signal_connect_object(player, "notify::station",
-	                        G_CALLBACK(on_player_notify_station), self, 0);
+				G_CALLBACK(on_player_notify_station), self, 0);
 	g_signal_handlers_connect_object(station_list, station_list_handlers, self, 0);
 
 	/* Chain up */
@@ -799,7 +740,7 @@ gv_stations_tree_view_class_init(GvStationsTreeViewClass *class)
 
 	/* Signals */
 	signals[SIGNAL_POPULATED] =
-	        g_signal_new("populated", G_TYPE_FROM_CLASS(class),
-	                     G_SIGNAL_RUN_LAST, 0, NULL, NULL, NULL,
+		g_signal_new("populated", G_TYPE_FROM_CLASS(class),
+			     G_SIGNAL_RUN_LAST, 0, NULL, NULL, NULL,
 			     G_TYPE_NONE, 0);
 }
